@@ -10,9 +10,8 @@ def test_all_modules_error(func):
     with pytest.raises(
         ValueError,
         match=(
-            "`modules_to_ignore` and "
-            "`modules_to_consider` cannot "
-            "be both specified."
+            r"'modules_to_ignore' and 'modules_to_consider' cannot "
+            r"be both specified."
         ),
     ):
         func(modules_to_ignore=["foo"], modules_to_consider=["bar"])
@@ -43,7 +42,7 @@ def test_number_public_functions():
     If this is intentional, then the number should be updated in the test.
     Otherwise it means that the public API of nilearn has changed by mistake.
     """
-    assert len({_[0] for _ in all_functions()}) == 264
+    assert len({_[0] for _ in all_functions(return_private=False)}) == 273
 
 
 @pytest.mark.skipif(
@@ -57,4 +56,4 @@ def test_number_public_classes():
     If this is intentional, then the number should be updated in the test.
     Otherwise it means that the public API of nilearn has changed by mistake.
     """
-    assert len({_[0] for _ in all_classes()}) == 67
+    assert len({_[0] for _ in all_classes()}) == 74
