@@ -2,20 +2,14 @@
 
 import numpy as np
 import pytest
-from nibabel import Nifti1Image
 from scipy.stats import scoreatpercentile
-from sklearn.base import BaseEstimator
 
 from nilearn._utils.extmath import fast_abs_percentile
 from nilearn._utils.param_validation import (
-    MNI152_BRAIN_VOLUME,
     _cast_to_int32,
-    _get_mask_extent,
-    check_feature_screening,
     check_params,
     check_threshold,
 )
-from nilearn.datasets import load_mni152_brain_mask
 
 
 @pytest.fixture
@@ -168,59 +162,6 @@ def test_check_threshold_for_error(matrix):
         )
 
 
-def test_get_mask_extent():
-    """Test that hard-coded standard mask volume can be corrected computed."""
-    assert _get_mask_extent(load_mni152_brain_mask()) == MNI152_BRAIN_VOLUME
-
-
-@pytest.mark.parametrize("is_classif", [True, False])
-@pytest.mark.parametrize("screening_percentile", [100, None, 20, 101, -1, 10])
-@pytest.mark.parametrize("roi_size", ["small", "large"])
-def test_feature_screening(
-    affine_eye, is_classif, screening_percentile, roi_size
-):
-    """Check that screening percentile is correctly adjusted.
-
-    For very small ROIs, all elements should be included.
-    """
-    mask_img_data = np.zeros((182, 218, 182))
-
-    if roi_size == "small":
-        mask_img_data[80:-80, 80:-80, 80:-80] = 1
-    else:
-        mask_img_data[40:-40, 40:-40, 40:-40] = 1
-
-    mask_img = Nifti1Image(mask_img_data, affine=affine_eye)
-
-    if screening_percentile == 100 or screening_percentile is None:
-        assert (
-            check_feature_screening(screening_percentile, mask_img, is_classif)
-            is None
-        )
-    elif screening_percentile in {-1, 101}:
-        with pytest.raises(ValueError):
-            check_feature_screening(
-                screening_percentile,
-                mask_img,
-                is_classif,
-            )
-    else:
-        if roi_size == "small":
-            with pytest.warns(
-                UserWarning, match="screening_percentile set to '100'"
-            ):
-                select_percentile = check_feature_screening(
-                    screening_percentile, mask_img, is_classif
-                )
-            assert select_percentile.percentile == 100
-        else:
-            select_percentile = check_feature_screening(
-                screening_percentile, mask_img, is_classif
-            )
-            assert screening_percentile <= select_percentile.percentile < 100
-        assert isinstance(select_percentile, BaseEstimator)
-
-
 @pytest.mark.parametrize("dtype", (np.uint8, np.uint16, np.uint32, np.int8))
 def test_sample_mask_signed(dtype):
     """Check unsigned sample_mask is converted to signed."""
@@ -253,7 +194,7 @@ def test_check_params():
 
     f_with_param_to_check(data_dir="foo")
 
-    with pytest.raises(TypeError, match="'data_dir' should be of type"):
+    with pytest.raises(TypeError, match="'data_dir' must be of type"):
         f_with_param_to_check(data_dir=1)
 
 
@@ -264,5 +205,5 @@ def test_check_params_not_necessary():
         check_params(locals())
         return foo
 
-    with pytest.raises(ValueError, match="No known parameter to check."):
+    with pytest.raises(ValueError, match=r"No known parameter to check."):
         f_with_unknown_param(foo=1)
