@@ -11,8 +11,10 @@ from sklearn.utils import Bunch
 
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
-from nilearn._utils.niimg_conversions import check_niimg
-from nilearn._utils.param_validation import check_params
+from nilearn._utils.param_validation import (
+    check_parameter_in_allowed,
+    check_params,
+)
 from nilearn.datasets._utils import (
     ALLOWED_DATA_TYPES,
     ALLOWED_MESH_TYPES,
@@ -21,7 +23,7 @@ from nilearn.datasets._utils import (
     get_dataset_descr,
     get_dataset_dir,
 )
-from nilearn.image import get_data, new_img_like, resampling
+from nilearn.image import check_niimg, get_data, new_img_like, resampling
 from nilearn.surface import (
     FileMesh,
     PolyMesh,
@@ -106,9 +108,10 @@ def fetch_icbm152_2009(data_dir=None, url=None, resume=True, verbose=1):
 
     Notes
     -----
+    %(fetcher_note)s
+
     For more information
     see the :ref:`dataset description <icbm_152_template>`.
-
     """
     check_params(locals())
 
@@ -157,7 +160,9 @@ def fetch_icbm152_2009(data_dir=None, url=None, resume=True, verbose=1):
 
     fdescr = get_dataset_descr(dataset_name)
 
-    params = dict([("description", fdescr), *list(zip(keys, sub_files))])
+    params = dict(
+        [("description", fdescr), *list(zip(keys, sub_files, strict=False))]
+    )
     return Bunch(**params)
 
 
@@ -176,7 +181,7 @@ def load_mni152_template(resolution=None):
     ----------
     %(resolution)s
 
-        .. versionadded:: 0.8.1
+        .. nilearn_versionadded:: 0.8.1
 
     Returns
     -------
@@ -214,12 +219,8 @@ def load_mni152_template(resolution=None):
     # Resample template according to the pre-specified resolution, if different
     # than 1
     if resolution != 1:
-        # TODO (nilearn >= 0.13.0) force_resample=True
         new_brain_template = resampling.resample_img(
-            new_brain_template,
-            np.eye(3) * resolution,
-            copy_header=True,
-            force_resample=False,
+            new_brain_template, np.eye(3) * resolution
         )
 
     return new_brain_template
@@ -235,7 +236,7 @@ def load_mni152_gm_template(resolution=None):
 
     %(templateflow)s
 
-    .. versionadded:: 0.8.1
+    .. nilearn_versionadded:: 0.8.1
 
     Parameters
     ----------
@@ -274,12 +275,8 @@ def load_mni152_gm_template(resolution=None):
     # Resample template according to the pre-specified resolution, if different
     # than 1
     if resolution != 1:
-        # TODO (nilearn >= 0.13.0) force_resample=True
         new_gm_template = resampling.resample_img(
-            new_gm_template,
-            np.eye(3) * resolution,
-            copy_header=True,
-            force_resample=False,
+            new_gm_template, np.eye(3) * resolution
         )
 
     return new_gm_template
@@ -296,7 +293,7 @@ def load_mni152_wm_template(resolution=None):
 
     %(templateflow)s
 
-    .. versionadded:: 0.8.1
+    .. nilearn_versionadded:: 0.8.1
 
     Parameters
     ----------
@@ -335,12 +332,8 @@ def load_mni152_wm_template(resolution=None):
     # Resample template according to the pre-specified resolution, if different
     # than 1
     if resolution != 1:
-        # TODO (nilearn >= 0.13.0) force_resample=True
         new_wm_template = resampling.resample_img(
-            new_wm_template,
-            np.eye(3) * resolution,
-            copy_header=True,
-            force_resample=False,
+            new_wm_template, np.eye(3) * resolution
         )
 
     return new_wm_template
@@ -355,13 +348,13 @@ def load_mni152_brain_mask(resolution=None, threshold=0.2):
 
     %(templateflow)s
 
-    .. versionadded:: 0.2.5
+    .. nilearn_versionadded:: 0.2.5
 
     Parameters
     ----------
     %(resolution)s
 
-        .. versionadded:: 0.8.1
+        .. nilearn_versionadded:: 0.8.1
 
     threshold : :obj:`float`, default=0.2
         Values of the MNI152 T1 template above this threshold will be included.
@@ -400,7 +393,7 @@ def load_mni152_gm_mask(resolution=None, threshold=0.2, n_iter=2):
 
     %(templateflow)s
 
-    .. versionadded:: 0.8.1
+    .. nilearn_versionadded:: 0.8.1
 
     Parameters
     ----------
@@ -454,7 +447,7 @@ def load_mni152_wm_mask(resolution=None, threshold=0.2, n_iter=2):
 
     %(templateflow)s
 
-    .. versionadded:: 0.8.1
+    .. nilearn_versionadded:: 0.8.1
 
     Parameters
     ----------
@@ -507,7 +500,7 @@ def fetch_icbm152_brain_gm_mask(
 
      %(templateflow)s
 
-    .. versionadded:: 0.2.5
+    .. nilearn_versionadded:: 0.2.5
 
     Parameters
     ----------
@@ -524,7 +517,7 @@ def fetch_icbm152_brain_gm_mask(
         and :term:`erosion<Erosion>` steps performed in
         scipy.ndimage.binary_closing function.
 
-        .. versionadded:: 0.8.1
+        .. nilearn_versionadded:: 0.8.1
 
     %(verbose)s
 
@@ -543,6 +536,8 @@ def fetch_icbm152_brain_gm_mask(
 
     Notes
     -----
+    %(fetcher_note)s
+
     This function relies on ICBM152 templates where we particularly pick
     gray matter template and threshold the template at .2 to take one fifth
     of the values. Then, do a bit post processing such as binary closing
@@ -553,7 +548,6 @@ def fetch_icbm152_brain_gm_mask(
 
     For more information
     see the :ref:`dataset description <icbm_152_template>`.
-
     """
     check_params(locals())
 
@@ -669,9 +663,10 @@ def fetch_oasis_vbm(
 
     Notes
     -----
+    %(fetcher_note)s
+
     For more information
     see the :ref:`dataset description <oasis_maps>`.
-
     """
     check_params(locals())
 
@@ -1025,7 +1020,7 @@ def _fetch_surf_fsaverage(dataset_name, data_dir=None):
 def load_fsaverage(mesh="fsaverage5", data_dir=None):
     """Load fsaverage for both hemispheres as PolyMesh objects.
 
-    .. versionadded:: 0.11.0
+    .. nilearn_versionadded:: 0.11.0
 
     Parameters
     ----------
@@ -1075,7 +1070,7 @@ def load_fsaverage_data(
 ):
     """Return freesurfer data on an fsaverage mesh as a SurfaceImage.
 
-    .. versionadded:: 0.11.0
+    .. nilearn_versionadded:: 0.11.0
 
     Parameters
     ----------
@@ -1106,17 +1101,8 @@ def load_fsaverage_data(
         SurfaceImage with the freesurfer mesh and data.
     """
     check_params(locals())
-
-    if mesh_type not in ALLOWED_MESH_TYPES:
-        raise ValueError(
-            f"'mesh_type' must be one of {ALLOWED_MESH_TYPES}.\n"
-            f"Got: {mesh_type=}."
-        )
-    if data_type not in ALLOWED_DATA_TYPES:
-        raise ValueError(
-            f"'data_type' must be one of {ALLOWED_DATA_TYPES}.\n"
-            f"Got: {data_type=}."
-        )
+    check_parameter_in_allowed(mesh_type, ALLOWED_MESH_TYPES, "mesh_type")
+    check_parameter_in_allowed(data_type, ALLOWED_DATA_TYPES, "data_type")
 
     fsaverage = load_fsaverage(mesh=mesh, data_dir=data_dir)
     fsaverage_data = fetch_surf_fsaverage(mesh=mesh, data_dir=data_dir)
