@@ -7,13 +7,6 @@ from warnings import warn
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 
-_GENERAL_MESSAGE = (
-    "The import path 'nilearn.datasets.utils'\n"
-    "will be deprecated in version 0.13.\n"
-    "Importing from 'nilearn.datasets.utils will be possible\n"
-    "at least until release 0.13.0."
-)
-
 
 @fill_doc
 def get_data_dirs(data_dir=None):
@@ -76,11 +69,12 @@ def load_sample_motor_activation_image():
     """
     from .func import load_sample_motor_activation_image as tmp
 
-    # TODO (nilearn >= 0.13.0)
+    # TODO (nilearn >= 0.14.0)
     warn(
-        f"{_GENERAL_MESSAGE}"
+        "Import from 'nilearn.datasets.utils'\n"
+        "will be deprecated in version 0.14.0.\n"
         "Please import this function from 'nilearn.datasets.func' instead.",
-        DeprecationWarning,
+        FutureWarning,
         stacklevel=find_stack_level(),
     )
     return tmp()
