@@ -26,15 +26,25 @@ from nilearn._utils import logger
 from nilearn._utils.cache_mixin import CacheMixin
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
-from nilearn._utils.masker_validation import check_embedded_masker
 from nilearn._utils.niimg import safe_get_data
-from nilearn._utils.niimg_conversions import check_niimg
-from nilearn._utils.param_validation import check_params
+from nilearn._utils.param_validation import (
+    check_is_of_allowed_type,
+    check_params,
+)
 from nilearn._utils.path_finding import resolve_globbing
 from nilearn._utils.tags import SKLEARN_LT_1_6
-from nilearn.maskers import NiftiMapsMasker, SurfaceMapsMasker, SurfaceMasker
+from nilearn.image import check_niimg
+from nilearn.maskers import (
+    MultiNiftiMasker,
+    MultiSurfaceMasker,
+    NiftiMapsMasker,
+    SurfaceMapsMasker,
+    SurfaceMasker,
+)
+from nilearn.maskers.masker_validation import check_embedded_masker
 from nilearn.signal import row_sum_of_squares
 from nilearn.surface import SurfaceImage
+from nilearn.typing import NiimgLike
 
 
 def _warn_ignored_surface_masker_params(estimator):
@@ -228,7 +238,7 @@ def _mask_and_reduce(
             n_samples=n_samples,
             random_state=random_state,
         )
-        for img, confound in zip(imgs, confounds)
+        for img, confound in zip(imgs, confounds, strict=False)
     )
 
     subject_n_samples = [subject_data.shape[0] for subject_data in data_list]
@@ -279,7 +289,7 @@ def _mask_and_reduce_single(
     else:
         n_samples = ceil(data_n_samples * reduction_ratio)
 
-    U, S, V = masker._cache(_fast_svd, func_memory_level=3)(
+    U, S, _ = masker._cache(_fast_svd, func_memory_level=3)(
         this_data.T, n_samples, random_state=random_state
     )
     U = U.T.copy()
@@ -293,7 +303,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
     Handles mask logic, provides transform and inverse_transform methods
 
-     .. versionadded:: 0.2
+     .. nilearn_versionadded:: 0.2
 
     Parameters
     ----------
@@ -303,19 +313,11 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
     %(random_state)s
 
-    mask : Niimg-like object,  :obj:`~nilearn.maskers.MultiNiftiMasker` or
-           :obj:`~nilearn.surface.SurfaceImage` or
-           :obj:`~nilearn.maskers.SurfaceMasker` object, optional
-        Mask to be used on data. If an instance of masker is passed,
-        then its mask will be used. If no mask is given, for Nifti images,
-        it will be computed automatically by a MultiNiftiMasker with default
-        parameters; for surface images, all the vertices will be used.
+    %(mask_decomposition)s
 
     %(smoothing_fwhm)s
 
-    standardize : boolean, default=True
-        If standardize is True, the time-series are centered and normed:
-        their mean is put to 0 and their variance to 1 in the time dimension.
+    %(standardize_true)s
 
     standardize_confounds : boolean, default=True
         If standardize_confounds is True, the confounds are z-scored:
@@ -514,11 +516,23 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
         self._fit_cache()
 
+        if self.mask is not None:
+            check_is_of_allowed_type(
+                self.mask,
+                (
+                    MultiSurfaceMasker,
+                    SurfaceImage,
+                    MultiNiftiMasker,
+                    *NiimgLike,
+                ),
+                "mask",
+            )
+
         masker_type = "multi_nii"
-        if isinstance(self.mask, (SurfaceMasker, SurfaceImage)) or any(
+        if isinstance(self.mask, (MultiSurfaceMasker, SurfaceImage)) or any(
             isinstance(x, SurfaceImage) for x in imgs
         ):
-            masker_type = "surface"
+            masker_type = "multi_surface"
             _warn_ignored_surface_masker_params(self)
         self.masker_ = check_embedded_masker(self, masker_type=masker_type)
         self.masker_.memory_level = self.memory_level
@@ -546,15 +560,22 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
         # Create and fit appropriate MapsMasker for transform
         # and inverse_transform
+        maps_masker_kwargs = {
+            "memory": self.memory,
+            "memory_level": self.memory_level,
+        }
         if isinstance(self.masker_, SurfaceMasker):
             self.maps_masker_ = SurfaceMapsMasker(
-                self.components_img_, self.masker_.mask_img_
+                self.components_img_,
+                self.masker_.mask_img_,
+                **maps_masker_kwargs,
             )
         else:
             self.maps_masker_ = NiftiMapsMasker(
                 self.components_img_,
                 self.masker_.mask_img_,
                 resampling_target="maps",
+                **maps_masker_kwargs,
             )
         self.maps_masker_.fit()
 
@@ -562,18 +583,6 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
         return self
 
-    @property
-    def nifti_maps_masker_(self):
-        # TODO (nilearn >= 0.13.0) remove
-        warnings.warn(
-            message="The 'nifti_maps_masker_' attribute is deprecated "
-            "and will be removed in Nilearn 0.13.0.\n"
-            "Please use 'maps_masker_' instead.",
-            category=FutureWarning,
-            stacklevel=find_stack_level(),
-        )
-        return self.maps_masker_
-
     def __sklearn_is_fitted__(self):
         return hasattr(self, "components_")
 
@@ -619,7 +628,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
         return [
             self.maps_masker_.transform(img, confounds=confound)
-            for img, confound in zip(imgs, confounds)
+            for img, confound in zip(imgs, confounds, strict=False)
         ]
 
     def inverse_transform(self, loadings):
