@@ -1,11 +1,10 @@
 """Test CanICA."""
 
-import sys
-
 import numpy as np
 import pytest
 from numpy.testing import assert_array_almost_equal
 
+from nilearn._utils.helpers import is_windows_platform
 from nilearn.decomposition.canica import CanICA
 from nilearn.decomposition.tests.conftest import (
     RANDOM_STATE,
@@ -21,10 +20,16 @@ def test_threshold_bound_error(canica_data_single_img):
     than the number of components.
     """
     with pytest.raises(ValueError, match="Threshold must not be higher"):
-        canica = CanICA(n_components=4, threshold=5.0, smoothing_fwhm=None)
+        canica = CanICA(
+            n_components=4,
+            threshold=5.0,
+            smoothing_fwhm=None,
+            standardize="zscore_sample",
+        )
         canica.fit(canica_data_single_img)
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("data_type", ["nifti", "surface"])
 def test_percentile_range(rng, canica_data_single_img):
     """Test that a warning is given when thresholds are stressed."""
@@ -35,17 +40,14 @@ def test_percentile_range(rng, canica_data_single_img):
         n_components=edge_case,
         threshold=float(edge_case),
         smoothing_fwhm=None,
+        standardize="zscore_sample",
     )
 
     with pytest.warns(UserWarning, match="obtained a critical threshold"):
         canica.fit(canica_data_single_img)
 
 
-# TODO (python >= 3.10) remove skipif when dropping python 3.9
-@pytest.mark.skipif(
-    sys.version_info[1] == 9,
-    reason="fails only on MacOS with python 3.9",
-)
+@pytest.mark.flaky(reruns=5, reruns_delay=2, condition=is_windows_platform())
 @pytest.mark.parametrize("data_type", ["nifti"])
 def test_canica_square_img(
     decomposition_mask_img, canica_components, canica_data
@@ -63,6 +65,7 @@ def test_canica_square_img(
         mask=decomposition_mask_img,
         smoothing_fwhm=smoothing_fwhm,
         n_init=50,
+        standardize="zscore_sample",
     )
     canica.fit(canica_data)
     maps = get_data(canica.components_img_)
@@ -85,7 +88,7 @@ def test_canica_square_img(
     assert_array_almost_equal(K_abs, 0, 1)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize("data_type", ["nifti", "surface"])
 def test_component_sign(canica_data, data_type):
     """Check sign of extracted components.
@@ -100,6 +103,7 @@ def test_component_sign(canica_data, data_type):
         n_components=4,
         random_state=RANDOM_STATE,
         smoothing_fwhm=None,
+        standardize="zscore_sample",
     )
 
     for _ in range(3):
