@@ -19,8 +19,9 @@ from numpy.testing import (
 )
 
 from nilearn._utils import testing
-from nilearn._utils.exceptions import DimensionError
 from nilearn._utils.niimg import is_binary_niimg
+from nilearn.conftest import _affine_eye
+from nilearn.exceptions import DimensionError
 from nilearn.image import get_data
 from nilearn.image.image import crop_img
 from nilearn.image.resampling import (
@@ -63,20 +64,6 @@ def data(rng, shape):
     return rng.random(shape)
 
 
-def test_resample_deprecation_force_resample(data, shape, affine_eye):
-    """Test change of value of force_resample."""
-    # TODO (nilearn 0.13.0)
-    affine_eye[:3, -1] = 0.5 * np.array(shape[:3])
-
-    with pytest.warns(FutureWarning, match="force_resample"):
-        resample_img(
-            Nifti1Image(data, affine_eye),
-            target_affine=affine_eye,
-            interpolation="nearest",
-            force_resample=None,
-        )
-
-
 @pytest.mark.parametrize("force_resample", [False, True])
 def test_identity_resample(data, force_resample, shape, affine_eye):
     """Test resampling with an identity affine."""
@@ -87,30 +74,53 @@ def test_identity_resample(data, force_resample, shape, affine_eye):
         target_affine=affine_eye,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert_almost_equal(data, get_data(rot_img))
 
-    # Test with a 3x3 affine
+
+@pytest.mark.parametrize(
+    "target_affine",
+    [
+        _affine_eye()[:3, :3],  # with a 3x3 affine
+        _affine_eye().tolist(),
+        _affine_eye()[:3, :3].tolist(),
+        tuple(_affine_eye().tolist()),
+        tuple(_affine_eye()[:3, :3].tolist()),
+    ],
+)
+@pytest.mark.parametrize("force_resample", [False, True])
+def test_identity_resample_array_like(
+    data, force_resample, affine_eye, target_affine
+):
+    """Test target_affine as non array."""
     rot_img = resample_img(
         Nifti1Image(data, affine_eye),
-        target_affine=affine_eye[:3, :3],
+        target_affine=target_affine,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert_almost_equal(data, get_data(rot_img))
 
-    # Smoke-test with a list affine
-    rot_img = resample_img(
-        Nifti1Image(data, affine_eye),
-        target_affine=affine_eye.tolist(),
-        interpolation="nearest",
-        force_resample=force_resample,
-        copy_header=True,
-    )
+
+@pytest.mark.parametrize(
+    "target_affine",
+    [
+        [1, 2, 3],
+        [[1, 2, 3]],
+        _affine_eye().ravel(),
+        _affine_eye()[:3, :3].ravel(),
+    ],
+)
+def test_target_affine_error(data, target_affine, affine_eye):
+    """Check errors when passing affine as array-like with wrong dimensions."""
+    with pytest.raises(np.linalg.LinAlgError):
+        resample_img(
+            Nifti1Image(data, affine_eye),
+            target_affine=target_affine,
+            interpolation="nearest",
+        )
 
 
 @pytest.mark.parametrize("force_resample", [False, True])
@@ -128,10 +138,9 @@ def test_identity_resample_non_native_endians(
 
     rot_img = resample_img(
         Nifti1Image(data.astype(endian_type), affine_eye),
-        target_affine=affine_eye.tolist(),
+        target_affine=affine_eye,
         interpolation=interpolation,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert_almost_equal(data, get_data(rot_img))
@@ -145,7 +154,6 @@ def test_downsample(data, force_resample, affine_eye):
         target_affine=2 * affine_eye,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     downsampled = data[::2, ::2, ::2, ...]
@@ -158,7 +166,6 @@ def test_downsample(data, force_resample, affine_eye):
         target_affine=2 * affine_eye,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert_almost_equal(get_data(rot_img_2), get_data(rot_img))
@@ -183,7 +190,6 @@ def test_downsample_non_native_endian_data(
         target_affine=2 * affine_eye,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     downsampled = data[::2, ::2, ::2, ...]
@@ -197,7 +203,6 @@ def test_downsample_non_native_endian_data(
         interpolation="nearest",
         copy=copy_data,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert_almost_equal(downsampled, get_data(rot_img)[:x, :y, :z, ...])
@@ -222,7 +227,6 @@ def test_resampling_fill_value(data, affine_eye, value, force_resample):
             fill_value=value,
             clip=False,
             force_resample=force_resample,
-            copy_header=True,
         )
     else:
         rot_img = resample_img(
@@ -231,7 +235,6 @@ def test_resampling_fill_value(data, affine_eye, value, force_resample):
             interpolation="nearest",
             clip=False,
             force_resample=force_resample,
-            copy_header=True,
         )
 
     assert get_data(rot_img).flatten()[0] == value
@@ -242,7 +245,6 @@ def test_resampling_fill_value(data, affine_eye, value, force_resample):
         interpolation="nearest",
         fill_value=value,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert get_data(rot_img2).flatten()[0] == value
@@ -263,7 +265,6 @@ def test_resampling_with_affine(data, affine_eye, angle, force_resample):
         target_affine=rot,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert np.max(data) == np.max(get_data(rot_img))
@@ -279,7 +280,6 @@ def test_resampling_with_affine(data, affine_eye, angle, force_resample):
         target_affine=rot,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert np.max(data) == np.max(get_data(rot_img))
@@ -299,14 +299,12 @@ def test_resampling_continuous_with_affine(
         target_affine=rot,
         interpolation="continuous",
         force_resample=force_resample,
-        copy_header=True,
     )
     rot_img_back = resample_img(
         rot_img,
         target_affine=affine_eye,
         interpolation="continuous",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     center = slice(1, 9)
@@ -330,13 +328,11 @@ def test_resampling_error_checks(tmp_path, force_resample, data, affine_eye):
         target_shape=target_shape,
         target_affine=affine_eye,
         force_resample=force_resample,
-        copy_header=True,
     )
     resample_img(
         img,
         target_affine=affine_eye,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     filename = testing.write_imgs_to_path(img, file_path=tmp_path)
@@ -345,7 +341,6 @@ def test_resampling_error_checks(tmp_path, force_resample, data, affine_eye):
         target_shape=target_shape,
         target_affine=affine_eye,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     # Missing parameter
@@ -354,28 +349,25 @@ def test_resampling_error_checks(tmp_path, force_resample, data, affine_eye):
             img,
             target_shape=target_shape,
             force_resample=force_resample,
-            copy_header=True,
         )
 
     # Invalid shape
-    with pytest.raises(ValueError, match="shape .* should be .* 3D grid"):
+    with pytest.raises(ValueError, match=r"shape .* should be .* 3D grid"):
         resample_img(
             img,
             target_shape=(2, 3),
             target_affine=affine_eye,
             force_resample=force_resample,
-            copy_header=True,
         )
 
     # Invalid interpolation
-    with pytest.raises(ValueError, match="interpolation must be one of"):
+    with pytest.raises(ValueError, match="'interpolation' must be one of"):
         resample_img(
             img,
             target_shape=target_shape,
             target_affine=affine_eye,
             interpolation="an_invalid_interpolation",
             force_resample=force_resample,
-            copy_header=True,
         )
 
 
@@ -394,7 +386,6 @@ def test_resampling_copy_has_no_shared_memory(
         target_shape=target_shape,
         copy=False,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert img_r == img
@@ -405,7 +396,6 @@ def test_resampling_copy_has_no_shared_memory(
         target_shape=target_shape,
         copy=True,
         force_resample=force_resample,
-        copy_header=True,
     )
 
     assert not np.may_share_memory(get_data(img_r), get_data(img))
@@ -426,7 +416,6 @@ def test_resampling_warning_s_form(data, affine_eye, force_resample):
             img_no_sform,
             target_affine=affine_eye,
             force_resample=force_resample,
-            copy_header=True,
         )
 
 
@@ -450,7 +439,6 @@ def test_resampling_warning_binary_image(affine_eye, rng, force_resample):
             target_affine=rot,
             interpolation="continuous",
             force_resample=force_resample,
-            copy_header=True,
         )
 
     with pytest.warns(Warning, match="Resampling binary images with"):
@@ -459,7 +447,6 @@ def test_resampling_warning_binary_image(affine_eye, rng, force_resample):
             target_affine=rot,
             interpolation="linear",
             force_resample=force_resample,
-            copy_header=True,
         )
 
 
@@ -469,7 +456,6 @@ def test_resample_img_copied_header(img_4d_mni_tr2, force_resample):
     result = resample_img(
         img_4d_mni_tr2,
         target_affine=np.diag((6, 6, 6)),
-        copy_header=True,
         force_resample=force_resample,
     )
     # pixdim[1:4] should change to [6, 6, 6]
@@ -519,20 +505,17 @@ def test_4d_affine_bounding_box_error(affine_eye, force_resample):
         target_affine=bigger_img.affine,
         target_shape=bigger_img.shape,
         force_resample=force_resample,
-        copy_header=True,
     )
     # resample using 3D affine and no target shape
     small_to_big_without_shape_3D_affine = resample_img(
         small_img,
         target_affine=bigger_img.affine[:3, :3],
-        copy_header=True,
         force_resample=force_resample,
     )
     # resample using 4D affine and no target shape
     small_to_big_without_shape = resample_img(
         small_img,
         target_affine=bigger_img.affine,
-        copy_header=True,
         force_resample=force_resample,
     )
 
@@ -572,7 +555,6 @@ def test_raises_upon_3x3_affine_and_no_shape(affine_eye, force_resample):
             target_affine=np.eye(3) * 2,
             target_shape=(10, 10, 10),
             force_resample=force_resample,
-            copy_header=True,
         )
 
 
@@ -598,10 +580,7 @@ def test_3x3_affine_bbox(affine_eye, force_resample):
     target_affine_3x3[1] *= -1
 
     img_3d_affine = resample_img(
-        img,
-        target_affine=target_affine_3x3,
-        force_resample=force_resample,
-        copy_header=True,
+        img, target_affine=target_affine_3x3, force_resample=force_resample
     )
 
     # If the bounding box is computed wrong, the image will be only zeros
@@ -656,10 +635,7 @@ def test_raises_bbox_error_if_data_outside_box(affine_eye, force_resample):
     for new_affine in new_affines:
         with pytest.raises(exception, match=message):
             resample_img(
-                img,
-                target_affine=new_affine,
-                force_resample=force_resample,
-                copy_header=True,
+                img, target_affine=new_affine, force_resample=force_resample
             )
 
 
@@ -688,10 +664,7 @@ def test_resampling_result_axis_permutation(
     target_affine = np.eye(3)[axis_permutation]
 
     resampled_img = resample_img(
-        source_img,
-        target_affine=target_affine,
-        force_resample=force_resample,
-        copy_header=True,
+        source_img, target_affine=target_affine, force_resample=force_resample
     )
 
     resampled_data = get_data(resampled_img)
@@ -706,10 +679,7 @@ def test_resampling_result_axis_permutation(
     target_affine[:3, 3] = offset
 
     resampled_img = resample_img(
-        source_img,
-        target_affine=target_affine,
-        force_resample=force_resample,
-        copy_header=True,
+        source_img, target_affine=target_affine, force_resample=force_resample
     )
 
     resampled_data = get_data(resampled_img)
@@ -750,10 +720,7 @@ def test_resampling_nan(affine_eye, core_shape, force_resample):
     # check 3x3 transformation matrix
     target_affine = np.eye(3)[axis_permutation]
     resampled_img = resample_img(
-        source_img,
-        target_affine=target_affine,
-        force_resample=force_resample,
-        copy_header=True,
+        source_img, target_affine=target_affine, force_resample=force_resample
     )
 
     resampled_data = get_data(resampled_img)
@@ -786,10 +753,7 @@ def test_resampling_nan_big(affine_eye, force_resample):
 
     with pytest.warns(RuntimeWarning):
         resampled_img = resample_img(
-            source_img,
-            target_affine=affine_eye,
-            force_resample=force_resample,
-            copy_header=True,
+            source_img, target_affine=affine_eye, force_resample=force_resample
         )
 
     resampled_data = get_data(resampled_img)
@@ -809,7 +773,6 @@ def test_resample_to_img(data, affine_eye, force_resample):
         target_img,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
     downsampled = data[::2, ::2, ::2, ...]
@@ -824,7 +787,7 @@ def test_crop(affine_eye):
     padded = pad_array(data, [3, 2, 4, 4, 5, 7])
     padd_nii = Nifti1Image(padded, affine_eye)
 
-    cropped = crop_img(padd_nii, pad=False, copy_header=True)
+    cropped = crop_img(padd_nii, pad=False)
 
     assert_equal(get_data(cropped), data)
 
@@ -853,7 +816,6 @@ def test_resample_identify_affine_int_translation(
         target_img,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
     assert_almost_equal(get_data(target_img), get_data(result_img))
 
@@ -862,7 +824,6 @@ def test_resample_identify_affine_int_translation(
         source_img,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
     assert_almost_equal(get_data(source_img), get_data(result_img_2))
 
@@ -871,7 +832,6 @@ def test_resample_identify_affine_int_translation(
         source_img,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
     assert_almost_equal(get_data(result_img_2), get_data(result_img_3))
 
@@ -880,7 +840,6 @@ def test_resample_identify_affine_int_translation(
         target_img,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
     assert_almost_equal(get_data(target_img), get_data(result_img_4))
 
@@ -903,7 +862,6 @@ def test_resample_clip(affine_eye, force_resample):
             target_affine=affine_eye,
             clip=False,
             force_resample=force_resample,
-            copy_header=True,
         )
     )
     clip_data = get_data(
@@ -912,7 +870,6 @@ def test_resample_clip(affine_eye, force_resample):
             target_affine=affine_eye,
             clip=True,
             force_resample=force_resample,
-            copy_header=True,
         )
     )
 
@@ -947,16 +904,13 @@ def test_reorder_img(affine_eye, rng, force_resample):
         new_affine = from_matrix_vector(rot, b)
 
         rot_img = resample_img(
-            ref_img,
-            target_affine=new_affine,
-            force_resample=force_resample,
-            copy_header=True,
+            ref_img, target_affine=new_affine, force_resample=force_resample
         )
 
         assert_array_equal(rot_img.affine, new_affine)
         assert_array_equal(get_data(rot_img).shape, shape)
 
-        reordered_img = reorder_img(rot_img, copy_header=True)
+        reordered_img = reorder_img(rot_img)
 
         assert_array_equal(reordered_img.affine[:3, :3], np.eye(3))
         assert_almost_equal(get_data(reordered_img), data)
@@ -972,16 +926,13 @@ def test_reorder_img_with_resample_arg(affine_eye, rng, force_resample):
 
     interpolation = "nearest"
 
-    reordered_img = reorder_img(
-        ref_img, resample=interpolation, copy_header=True
-    )
+    reordered_img = reorder_img(ref_img, resample=interpolation)
 
     resampled_img = resample_img(
         ref_img,
         target_affine=reordered_img.affine,
         interpolation=interpolation,
         force_resample=force_resample,
-        copy_header=True,
     )
     assert_array_equal(get_data(reordered_img), get_data(resampled_img))
 
@@ -997,10 +948,10 @@ def test_reorder_img_error_reorder_axis(affine_eye, rng):
     ref_img = Nifti1Image(data, non_diagonal_affine)
 
     # Test that no exception is raised when resample='continuous'
-    reorder_img(ref_img, resample="continuous", copy_header=True)
+    reorder_img(ref_img, resample="continuous")
 
     with pytest.raises(ValueError, match="Cannot reorder the axes"):
-        reorder_img(ref_img, copy_header=True)
+        reorder_img(ref_img)
 
 
 def test_reorder_img_flipping_axis(affine_eye, rng):
@@ -1018,7 +969,7 @@ def test_reorder_img_flipping_axis(affine_eye, rng):
         img = Nifti1Image(data, affine)
         orig_img = copy.copy(img)
 
-        img2 = reorder_img(img, copy_header=True)
+        img2 = reorder_img(img)
 
         # Check that img has not been changed
         assert_array_equal(img.affine, orig_img.affine)
@@ -1038,10 +989,8 @@ def test_reorder_img_error_interpolation(affine_eye, rng):
     affine[1, 0] = 0.1
     ref_img = Nifti1Image(data, affine)
 
-    with pytest.raises(ValueError, match="interpolation must be one of"):
-        reorder_img(
-            ref_img, resample="an_invalid_interpolation", copy_header=True
-        )
+    with pytest.raises(ValueError, match="'interpolation' must be one of"):
+        reorder_img(ref_img, resample="an_invalid_interpolation")
 
 
 @pytest.mark.parametrize("force_resample", [False, True])
@@ -1060,10 +1009,7 @@ def test_reorder_img_non_native_endianness(force_resample):
 
         img = Nifti1Image(data, affine)
         return resample_img(
-            img,
-            target_affine=affine,
-            force_resample=force_resample,
-            copy_header=True,
+            img, target_affine=affine, force_resample=force_resample
         )
 
     img_1 = _get_resampled_img("<f8")
@@ -1082,7 +1028,7 @@ def test_reorder_img_mirror():
         ]
     )
     img = Nifti1Image(np.zeros((4, 6, 8)), affine=affine)
-    reordered = reorder_img(img, copy_header=True)
+    reordered = reorder_img(img)
     assert_allclose(
         get_bounds(reordered.shape, reordered.affine),
         get_bounds(img.shape, img.affine),
@@ -1091,7 +1037,7 @@ def test_reorder_img_mirror():
 
 def test_reorder_img_copied_header(img_4d_mni_tr2):
     # Test that the header is copied when reordering
-    result = reorder_img(img_4d_mni_tr2, copy_header=True)
+    result = reorder_img(img_4d_mni_tr2)
     # all header fields should stay the same
     match_headers_keys(
         img_4d_mni_tr2,
@@ -1100,21 +1046,6 @@ def test_reorder_img_copied_header(img_4d_mni_tr2):
     )
 
 
-@pytest.mark.parametrize(
-    "func, input_img",
-    [
-        (resample_img, "img_4d_mni_tr2"),
-        (reorder_img, "img_4d_mni_tr2"),
-    ],
-)
-def test_warning_copy_header_false(request, func, input_img):
-    # Use the request fixture to get the actual fixture value
-    actual_input_img = request.getfixturevalue(input_img)
-    # TODO (nilearn 0.13.0)
-    with pytest.warns(FutureWarning, match="From release 0.13.0 onwards*"):
-        func(actual_input_img, copy_header=False)
-
-
 def test_coord_transform_trivial(affine_eye, rng):
     sform = affine_eye
     x = rng.random((10,))
@@ -1189,7 +1120,6 @@ def test_resample_img_segmentation_fault(force_resample):
             target_affine=aff_out,
             interpolation="nearest",
             force_resample=force_resample,
-            copy_header=True,
         )
 
 
@@ -1214,10 +1144,7 @@ def test_resampling_with_int_types_no_crash(affine_eye, dtype, force_resample):
     data = np.zeros((2, 2, 2))
     img = Nifti1Image(data.astype(dtype), affine_eye)
     resample_img(
-        img,
-        target_affine=2.0 * affine_eye,
-        force_resample=force_resample,
-        copy_header=True,
+        img, target_affine=2.0 * affine_eye, force_resample=force_resample
     )
 
 
@@ -1234,10 +1161,7 @@ def test_resampling_with_int64_types_no_crash(
     hdr.set_data_dtype(dtype)
     img = Nifti1Image(data.astype(dtype), affine_eye, header=hdr)
     resample_img(
-        img,
-        target_affine=2.0 * affine_eye,
-        force_resample=force_resample,
-        copy_header=True,
+        img, target_affine=2.0 * affine_eye, force_resample=force_resample
     )
 
 
@@ -1257,7 +1181,6 @@ def test_resample_input(affine_eye, shape, rng, tmp_path, force_resample):
         target_affine=affine,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
 
@@ -1272,7 +1195,6 @@ def test_smoke_resampling_non_nifti(affine_eye, shape, rng, force_resample):
         target_affine=target_affine,
         interpolation="nearest",
         force_resample=force_resample,
-        copy_header=True,
     )
 
 
