@@ -2,35 +2,37 @@
 
 import warnings
 from copy import deepcopy
-from typing import Union
+from typing import Any
 
 import numpy as np
 import pandas as pd
 from nibabel import Nifti1Image
 from sklearn.utils.estimator_checks import check_is_fitted
 
-from nilearn._utils.bids import (
-    sanitize_look_up_table,
-)
+from nilearn._utils.bids import sanitize_look_up_table
 from nilearn._utils.class_inspect import get_params
 from nilearn._utils.docs import fill_doc
+from nilearn._utils.helpers import is_matplotlib_installed
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import safe_get_data
-from nilearn._utils.niimg_conversions import (
-    check_niimg,
-    check_niimg_3d,
-    check_same_fov,
-)
 from nilearn._utils.param_validation import (
+    check_parameter_in_allowed,
     check_params,
     check_reduction_strategy,
 )
-from nilearn.image import get_data, load_img, resample_img
+from nilearn.image import (
+    check_niimg,
+    check_niimg_3d,
+    get_data,
+    load_img,
+    resample_img,
+)
+from nilearn.image.image import check_same_fov
+from nilearn.maskers._mixin import _LabelMaskerMixin
 from nilearn.maskers._utils import compute_middle_image
 from nilearn.maskers.base_masker import (
     BaseMasker,
     filter_and_extract,
-    generate_lut,
     mask_logger,
 )
 from nilearn.masking import load_mask_img
@@ -69,7 +71,7 @@ class _ExtractionFunctor:
 
 
 @fill_doc
-class NiftiLabelsMasker(BaseMasker):
+class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
     """Class for extracting data from Niimg-like objects \
        using labels of non-overlapping brain regions.
 
@@ -122,7 +124,7 @@ class NiftiLabelsMasker(BaseMasker):
 
     %(smoothing_fwhm)s
 
-    %(standardize_maskers)s
+    %(standardize_false)s
 
     %(standardize_confounds)s
 
@@ -168,16 +170,13 @@ class NiftiLabelsMasker(BaseMasker):
         Only relevant for the report figures.
 
     %(clean_args)s
-        .. versionadded:: 0.12.0
 
-    %(masker_kwargs)s
+        .. nilearn_versionadded:: 0.12.0
 
     Attributes
     ----------
     %(clean_args_)s
 
-    %(masker_kwargs_)s
-
     labels_img_ : :obj:`nibabel.nifti1.Nifti1Image`
         The labels image.
 
@@ -196,6 +195,8 @@ class NiftiLabelsMasker(BaseMasker):
 
     """
 
+    _template_name = "body_nifti_labels_masker.jinja"
+
     # memory and memory_level are used by _utils.CacheMixin.
 
     def __init__(
@@ -219,11 +220,10 @@ class NiftiLabelsMasker(BaseMasker):
         memory_level=1,
         verbose=0,
         strategy="mean",
-        keep_masked_labels=True,
+        keep_masked_labels=False,
         reports=True,
         cmap="CMRmap_r",
         clean_args=None,
-        **kwargs,  # TODO (nilearn >= 0.13.0) remove
     ):
         self.labels_img = labels_img
         self.background_label = background_label
@@ -248,9 +248,6 @@ class NiftiLabelsMasker(BaseMasker):
         self.dtype = dtype
         self.clean_args = clean_args
 
-        # TODO (nilearn >= 0.13.0) remove
-        self.clean_kwargs = kwargs
-
         # Parameters for resampling
         self.resampling_target = resampling_target
 
@@ -265,6 +262,16 @@ class NiftiLabelsMasker(BaseMasker):
 
         self.strategy = strategy
 
+        self._report_content = {
+            "description": (
+                "This report shows the regions "
+                "defined by the labels of the mask."
+            ),
+            "number_of_regions": 0,
+            "summary": {},
+            "warning_messages": [],
+        }
+
     @property
     def _region_id_name(self):
         """Return dictionary used to store region names and
@@ -278,80 +285,6 @@ class NiftiLabelsMasker(BaseMasker):
             .to_dict()
         )
 
-    @property
-    def labels_(self) -> list[Union[int, float]]:
-        """Return list of labels of the regions.
-
-        The background label is included if present in the image.
-        """
-        check_is_fitted(self)
-        lut = self.lut_
-        if hasattr(self, "_lut_"):
-            lut = self._lut_
-        return lut["index"].to_list()
-
-    @property
-    def region_names_(self) -> dict[int, str]:
-        """Return a dictionary containing the region names corresponding \
-            to each column in the array returned by `transform`.
-
-        The region names correspond to the labels provided
-        in labels in input.
-        The region name corresponding to ``region_signal[:,i]``
-        is ``region_names_[i]``.
-
-        .. versionadded:: 0.10.3
-        """
-        check_is_fitted(self)
-
-        index = self.labels_
-        valid_ids = [id for id in index if id != self.background_label]
-
-        sub_df = self.lut_[self.lut_["index"].isin(valid_ids)]
-
-        return sub_df["name"].reset_index(drop=True).to_dict()
-
-    @property
-    def region_ids_(self) -> dict[Union[str, int], Union[int, float]]:
-        """Return dictionary containing the region ids corresponding \
-           to each column in the array \
-           returned by `transform`.
-
-        The region id corresponding to ``region_signal[:,i]``
-        is ``region_ids_[i]``.
-        ``region_ids_['background']`` is the background label.
-
-        .. versionadded:: 0.10.3
-        """
-        check_is_fitted(self)
-
-        index = self.labels_
-
-        region_ids_: dict[Union[str, int], Union[int, float]] = {}
-        if self.background_label in index:
-            index.pop(index.index(self.background_label))
-            region_ids_["background"] = self.background_label
-        for i, id in enumerate(index):
-            region_ids_[i] = id  # noqa : PERF403
-
-        return region_ids_
-
-    @property
-    def n_elements_(self) -> int:
-        """Return number of regions.
-
-        This is equal to the number of unique values
-        in the fitted label image,
-        minus the background value.
-
-        .. versionadded:: 0.9.2
-        """
-        check_is_fitted(self)
-        lut = self.lut_
-        if hasattr(self, "_lut_"):
-            lut = self._lut_
-        return len(lut[lut["index"] != self.background_label])
-
     def _post_masking_atlas(self, visualize=False):
         """
         Find the masked atlas before transform and return it.
@@ -388,41 +321,54 @@ class NiftiLabelsMasker(BaseMasker):
 
         return masked_atlas, removed_region_ids, removed_region_names, display
 
-    def generate_report(self):
-        """Generate a report."""
+    def generate_report(self, title: str | None = None):
+        """Generate an HTML report for the current object.
+
+        Parameters
+        ----------
+        title : :obj:`str` or None, default=None
+            title for the report. If None, title will be the class name.
+
+        Returns
+        -------
+        report : `nilearn.reporting.html_report.HTMLReport`
+            HTML report for the masker.
+        """
         from nilearn.reporting.html_report import generate_report
 
+        self._report_content["title"] = title
+
+        if self._has_report_data():
+            img = self._reporting_data["images"]
+
+            if img is None:
+                msg = (
+                    f"No image provided to fit in {self.__class__.__name__}. "
+                    "Plotting ROIs of label image on the "
+                    "MNI152Template for reporting."
+                )
+                self._report_content["warning_messages"].append(msg)
+
+            elif self._reporting_data["dim"] == 5:
+                msg = (
+                    "A list of 4D subject images were provided to fit. "
+                    "Only first subject is shown in the report."
+                )
+                self._report_content["warning_messages"].append(msg)
+
         return generate_report(self)
 
     def _reporting(self):
-        """Return a list of all displays to be rendered.
+        """Return a figure to be rendered.
 
         Returns
         -------
-        displays : list
-            A list of all displays to be rendered.
-
+        :class:`~matplotlib.figure.Figure` or None
         """
-        import matplotlib.pyplot as plt
+        if not self._has_report_data():
+            return None
 
-        from nilearn import plotting
-
-        labels_image = None
-        if self._reporting_data is not None:
-            labels_image = self._reporting_data["labels_image"]
-
-        if (
-            labels_image is None
-            or not self.__sklearn_is_fitted__
-            or not self.reports
-        ):
-            self._report_content["summary"] = None
-            return [None]
-
-        # Remove warning message in case where the masker was
-        # previously fitted with no func image and is re-fitted
-        if "warning_message" in self._report_content:
-            self._report_content["warning_message"] = None
+        labels_image = self._reporting_data["labels_image"]
 
         table = self.lut_.copy()
         if hasattr(self, "_lut_"):
@@ -442,7 +388,10 @@ class NiftiLabelsMasker(BaseMasker):
 
         voxel_volume = np.abs(np.linalg.det(labels_image_affine[:3, :3]))
 
-        new_columns = {"size (in mm^3)": [], "relative size (in %)": []}
+        new_columns: dict[str, Any] = {
+            "size (in mm^3)": [],
+            "relative size (in %)": [],
+        }
         for label in table["label value"].to_list():
             size = len(labels_image_data[labels_image_data == label])
             new_columns["size (in mm^3)"].append(round(size * voxel_volume))
@@ -467,24 +416,33 @@ class NiftiLabelsMasker(BaseMasker):
         self._report_content["summary"] = table
         self._report_content["number_of_regions"] = self.n_elements_
 
-        img = self._reporting_data["img"]
+        return self._create_figure_for_report(labels_image)
+
+    def _create_figure_for_report(self, labels_image):
+        """Generate figure to include in the report.
+
+        Returns
+        -------
+        list of :class:`~matplotlib.figure.Figure` or None
+        """
+        if not is_matplotlib_installed():
+            return None
+
+        import matplotlib.pyplot as plt
+
+        from nilearn.plotting import find_xyz_cut_coords, plot_img, plot_roi
 
         # compute the cut coordinates on the label image in case
         # we have a functional image
-        cut_coords = plotting.find_xyz_cut_coords(
+        cut_coords = find_xyz_cut_coords(
             labels_image, activation_threshold=0.5
         )
 
+        img = self._reporting_data["images"]
+
         # If we have a func image to show in the report, use it
         if img is not None:
-            if self._reporting_data["dim"] == 5:
-                msg = (
-                    "A list of 4D subject images were provided to fit. "
-                    "Only first subject is shown in the report."
-                )
-                warnings.warn(msg, stacklevel=find_stack_level())
-                self._report_content["warning_message"] = msg
-            display = plotting.plot_img(
+            display = plot_img(
                 img,
                 cut_coords=cut_coords,
                 black_bg=False,
@@ -496,14 +454,7 @@ class NiftiLabelsMasker(BaseMasker):
         # Otherwise, simply plot the ROI of the label image
         # and give a warning to the user
         else:
-            msg = (
-                "No image provided to fit in NiftiLabelsMasker. "
-                "Plotting ROIs of label image on the "
-                "MNI152Template for reporting."
-            )
-            warnings.warn(msg, stacklevel=find_stack_level())
-            self._report_content["warning_message"] = msg
-            display = plotting.plot_roi(labels_image)
+            display = plot_roi(labels_image)
             plt.close()
 
         # If we have a mask, show its contours
@@ -515,7 +466,7 @@ class NiftiLabelsMasker(BaseMasker):
                 linewidths=3,
             )
 
-        return [display]
+        return display
 
     @fill_doc
     def fit(self, imgs=None, y=None):
@@ -531,25 +482,20 @@ class NiftiLabelsMasker(BaseMasker):
         """
         del y
         check_params(self.__dict__)
+
         check_reduction_strategy(self.strategy)
+        check_parameter_in_allowed(
+            self.resampling_target,
+            ("labels", "data", None),
+            "resampling_target",
+        )
 
-        if self.resampling_target not in ("labels", "data", None):
-            raise ValueError(
-                "invalid value for 'resampling_target' "
-                f"parameter: {self.resampling_target}"
-            )
+        # Reset warning message
+        # in case where the masker was previously fitted
+        self._report_content["warning_messages"] = []
 
-        self._sanitize_cleaning_parameters()
         self.clean_args_ = {} if self.clean_args is None else self.clean_args
 
-        self._report_content = {
-            "description": (
-                "This reports shows the regions "
-                "defined by the labels of the mask."
-            ),
-            "warning_message": None,
-        }
-
         self._fit_cache()
 
         mask_logger("load_regions", self.labels_img, verbose=self.verbose)
@@ -569,9 +515,7 @@ class NiftiLabelsMasker(BaseMasker):
                 idx = self.labels.index("background")
                 self.labels[idx] = "Background"
 
-        self.lut_ = generate_lut(
-            self.labels_img_, self.background_label, self.lut, self.labels
-        )
+        self.lut_ = self._generate_lut()
 
         self._original_region_ids = self.lut_["index"].to_list()
 
@@ -616,32 +560,28 @@ class NiftiLabelsMasker(BaseMasker):
         ):
             mask_logger("resample_mask", verbose=self.verbose)
 
-            # TODO (nilearn >= 0.13.0) force_resample=True
             self.mask_img_ = self._cache(resample_img, func_memory_level=2)(
                 self.mask_img_,
                 interpolation="nearest",
                 target_shape=ref_img.shape[:3],
                 target_affine=ref_img.affine,
-                copy_header=True,
-                force_resample=False,
             )
 
             # Just check that the mask is valid
             load_mask_img(self.mask_img_)
 
+        self._report_content["reports_at_fit_time"] = self.reports
         if self.reports:
             self._reporting_data = {
                 "labels_image": self.labels_img_,
                 "mask": self.mask_img_,
                 "dim": None,
-                "img": imgs,
+                "images": imgs,
             }
             if imgs is not None:
                 imgs, dims = compute_middle_image(imgs)
-                self._reporting_data["img"] = imgs
+                self._reporting_data["images"] = imgs
                 self._reporting_data["dim"] = dims
-        else:
-            self._reporting_data = None
 
         mask_logger("fit_done", verbose=self.verbose)
 
@@ -655,10 +595,10 @@ class NiftiLabelsMasker(BaseMasker):
         labels = self.labels
         if not isinstance(labels, list):
             raise TypeError(
-                f"'labels' must be a list. Got: {type(labels)}",
+                f"'labels' must be a list. Got: {labels.__class__.__name__}",
             )
         if not all(isinstance(x, str) for x in labels):
-            types_labels = {type(x) for x in labels}
+            types_labels = {x.__class__.__name__ for x in labels}
             raise TypeError(
                 "All elements of 'labels' must be a string.\n"
                 f"Got a list of {types_labels}",
@@ -692,7 +632,7 @@ class NiftiLabelsMasker(BaseMasker):
 
         %(sample_mask)s
 
-            .. versionadded:: 0.8.0
+            .. nilearn_versionadded:: 0.8.0
 
         Returns
         -------
@@ -721,7 +661,7 @@ class NiftiLabelsMasker(BaseMasker):
 
         %(sample_mask)s
 
-            .. versionadded:: 0.8.0
+            .. nilearn_versionadded:: 0.8.0
 
         Attributes
         ----------
@@ -732,7 +672,7 @@ class NiftiLabelsMasker(BaseMasker):
             that takes the value ``region_ids_[i]``
             is used to compute the signal in ``region_signal[:, i]``.
 
-            .. versionadded:: 0.10.3
+            .. nilearn_versionadded:: 0.10.3
 
         Returns
         -------
@@ -796,8 +736,6 @@ class NiftiLabelsMasker(BaseMasker):
                     interpolation="nearest",
                     target_shape=imgs_.shape[:3],
                     target_affine=imgs_.affine,
-                    copy_header=True,
-                    force_resample=False,
                 )
 
             # Remove imgs_ from memory before loading the same image
@@ -818,9 +756,8 @@ class NiftiLabelsMasker(BaseMasker):
         params["target_shape"] = target_shape
         params["target_affine"] = target_affine
         params["clean_kwargs"] = self.clean_args_
-        # TODO (nilearn  >= 0.13.0) remove
-        if self.clean_kwargs:
-            params["clean_kwargs"] = self.clean_kwargs_
+
+        sklearn_output_config = getattr(self, "_sklearn_output_config", None)
 
         region_signals, (ids, masked_atlas) = self._cache(
             filter_and_extract,
@@ -844,6 +781,7 @@ class NiftiLabelsMasker(BaseMasker):
             memory=self.memory_,
             memory_level=self.memory_level,
             verbose=self.verbose,
+            sklearn_output_config=sklearn_output_config,
         )
 
         # Create a lut that may be different from the fitted lut_
@@ -880,8 +818,6 @@ class NiftiLabelsMasker(BaseMasker):
             interpolation="nearest",
             target_shape=imgs_.shape[:3],
             target_affine=imgs_.affine,
-            copy_header=True,
-            force_resample=False,
         )
         labels_after_resampling = set(np.unique(safe_get_data(labels_img_)))
         if labels_diff := labels_before_resampling.difference(
@@ -904,7 +840,7 @@ class NiftiLabelsMasker(BaseMasker):
 
         Any mask given at initialization is taken into account.
 
-        .. versionchanged:: 0.9.2
+        .. nilearn_versionchanged:: 0.9.2
 
             This method now supports 1D arrays, which will produce 3D images.
 
