@@ -20,7 +20,7 @@ from nilearn.conftest import _img_labels
 from nilearn.image import get_data
 from nilearn.maskers import MultiNiftiLabelsMasker
 
-ESTIMATORS_TO_CHECK = [MultiNiftiLabelsMasker()]
+ESTIMATORS_TO_CHECK = [MultiNiftiLabelsMasker(standardize=None)]
 
 if SKLEARN_LT_1_6:
 
@@ -52,11 +52,13 @@ else:
         check(estimator)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "estimator, check, name",
     nilearn_check_estimator(
-        estimators=[MultiNiftiLabelsMasker(labels_img=_img_labels())]
+        estimators=[
+            MultiNiftiLabelsMasker(labels_img=_img_labels(), standardize=None)
+        ]
     ),
 )
 def test_check_estimator_nilearn(estimator, check, name):  # noqa: ARG001
@@ -64,7 +66,7 @@ def test_check_estimator_nilearn(estimator, check, name):  # noqa: ARG001
     check(estimator)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 def test_multi_nifti_labels_masker(
     affine_eye, n_regions, shape_3d_default, length, img_labels
 ):
@@ -81,12 +83,18 @@ def test_multi_nifti_labels_masker(
     assert signals11.shape == (length, n_regions)
 
     # No exception should be raised either
-    masker11 = MultiNiftiLabelsMasker(img_labels, resampling_target=None)
+    masker11 = MultiNiftiLabelsMasker(
+        img_labels, resampling_target=None, standardize=None
+    )
     masker11.fit()
     masker11.inverse_transform(signals11)
 
     masker11 = MultiNiftiLabelsMasker(
-        img_labels, mask_img=mask11_img, resampling_target=None
+        img_labels,
+        mask_img=mask11_img,
+        resampling_target=None,
+        keep_masked_labels=True,
+        standardize=None,
     )
     signals11 = masker11.fit_transform(fmri11_img)
 
@@ -99,7 +107,9 @@ def test_multi_nifti_labels_masker(
     for signals in signals11_list:
         assert signals.shape == (length, n_regions)
 
-    masker11 = MultiNiftiLabelsMasker(img_labels, resampling_target=None)
+    masker11 = MultiNiftiLabelsMasker(
+        img_labels, resampling_target=None, standardize=None
+    )
     signals11_list = masker11.fit_transform(signals_input)
 
     for signals in signals11_list:
@@ -113,6 +123,7 @@ def test_multi_nifti_labels_masker(
         assert_almost_equal(fmri11_img_r.affine, fmri11_img.affine)
 
 
+@pytest.mark.slow
 def test_multi_nifti_labels_masker_errors(
     affine_eye, shape_3d_default, length, img_labels
 ):
@@ -132,11 +143,11 @@ def test_multi_nifti_labels_masker_errors(
     masker11.fit()
 
     with pytest.raises(
-        ValueError, match="Images have different affine matrices."
+        ValueError, match=r"Images have different affine matrices."
     ):
         masker11.transform(fmri12_img)
 
-    with pytest.raises(ValueError, match="Images have incompatible shapes."):
+    with pytest.raises(ValueError, match=r"Images have incompatible shapes."):
         masker11.transform(fmri21_img)
 
     masker11 = MultiNiftiLabelsMasker(
@@ -161,7 +172,7 @@ def test_multi_nifti_labels_masker_errors(
 def test_multi_nifti_labels_masker_errors_strategy(img_labels):
     """Test strategy errors."""
     masker = MultiNiftiLabelsMasker(img_labels, strategy="TESTRAISE")
-    with pytest.raises(ValueError, match="Invalid strategy 'TESTRAISE'"):
+    with pytest.raises(ValueError, match="'strategy' must be one of"):
         masker.fit()
 
 
@@ -174,12 +185,11 @@ def test_multi_nifti_labels_masker_errors_resampling(
         img_labels,
         resampling_target=resampling_target,
     )
-    with pytest.raises(
-        ValueError, match="invalid value for 'resampling_target' parameter"
-    ):
+    with pytest.raises(ValueError, match="'resampling_target' must be one of"):
         masker.fit()
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("test_values", [[-2.0, -1.0, 0.0, 1.0, 2]])
 @pytest.mark.parametrize(
     "strategy, fn",
@@ -208,7 +218,9 @@ def test_multi_nifti_labels_masker_reduction_strategies(
     img = Nifti1Image(img_data, affine_eye)
     labels = Nifti1Image(labels_data, affine_eye)
 
-    masker = MultiNiftiLabelsMasker(labels, strategy=strategy)
+    masker = MultiNiftiLabelsMasker(
+        labels, strategy=strategy, standardize=None
+    )
     # Here passing [img, img] within a list because it is multiple subjects
     # with a 3D object.
     results = masker.fit_transform([img, img])
@@ -223,6 +235,7 @@ def test_multi_nifti_labels_masker_reduction_strategies(
     assert default_masker.strategy == "mean"
 
 
+@pytest.mark.slow
 def test_multi_nifti_labels_masker_resampling(
     affine_eye, n_regions, length, img_labels
 ):
@@ -242,7 +255,11 @@ def test_multi_nifti_labels_masker_resampling(
 
     # Target: labels
     masker = MultiNiftiLabelsMasker(
-        img_labels, mask_img=mask22_img, resampling_target="labels"
+        img_labels,
+        mask_img=mask22_img,
+        resampling_target="labels",
+        keep_masked_labels=True,
+        standardize=None,
     )
 
     fmri11_img = [fmri11_img, fmri11_img]
@@ -263,6 +280,7 @@ def test_multi_nifti_labels_masker_resampling(
         assert fmri11_img_r.shape == (masker.labels_img_.shape[:3] + (length,))
 
 
+@pytest.mark.slow
 def test_multi_nifti_labels_masker_resampling_clipped_labels(
     affine_eye, n_regions, length, img_labels, img_fmri
 ):
@@ -282,7 +300,11 @@ def test_multi_nifti_labels_masker_resampling_clipped_labels(
     fmri11_img = [img_fmri, img_fmri]
 
     masker = MultiNiftiLabelsMasker(
-        img_labels, mask_img=mask22_img, resampling_target="labels"
+        img_labels,
+        mask_img=mask22_img,
+        resampling_target="labels",
+        keep_masked_labels=True,
+        standardize=None,
     )
 
     signals = masker.fit_transform(fmri11_img)
@@ -306,6 +328,7 @@ def test_multi_nifti_labels_masker_resampling_clipped_labels(
         assert fmri11_img_r.shape == (masker.labels_img_.shape[:3] + (length,))
 
 
+@pytest.mark.slow
 def test_multi_nifti_labels_masker_atlas_data_different_fov(
     affine_eye, img_labels, length
 ):
@@ -330,6 +353,7 @@ def test_multi_nifti_labels_masker_atlas_data_different_fov(
     assert_array_equal(masker.labels_img_.affine, affine2)
 
 
+@pytest.mark.slow
 def test_multi_nifti_labels_masker_resampling_target():
     """Test labels masker with resampling target in 'data', 'labels'.
 
@@ -347,7 +371,9 @@ def test_multi_nifti_labels_masker_resampling_target():
     )
     for resampling_target in ["data", "labels"]:
         masker = MultiNiftiLabelsMasker(
-            labels_img=labels_img, resampling_target=resampling_target
+            labels_img=labels_img,
+            resampling_target=resampling_target,
+            keep_masked_labels=True,
         )
         if resampling_target == "data":
             with pytest.warns(
