@@ -1,5 +1,7 @@
 """Tests for the permuted_ols function."""
 
+import warnings
+
 import numpy as np
 import pytest
 from nibabel import Nifti1Image
@@ -168,8 +170,6 @@ def permuted_ols_no_intercept(tested_var, target_var, n_perm, i):
         n_perm=n_perm,
         two_sided_test=False,
         random_state=i,
-        output_type="dict",
-        verbose=1,
     )
     assert_equal(output["h0_max_t"].shape, (n_regressors, n_perm))
     return output["h0_max_t"]
@@ -184,8 +184,6 @@ def permuted_ols_with_intercept(tested_var, target_var, n_perm, i):
         n_perm=n_perm,
         two_sided_test=False,
         random_state=i,
-        output_type="dict",
-        verbose=1,
     )
     # pval should not be significant
     assert_array_less(output["logp_max_t"], 1.0)
@@ -222,7 +220,7 @@ def check_ktest_p_values_distribution_and_mse(all_kstest_pvals, all_mse):
     assert_array_less(np.diff(all_mse.mean(1)), 0)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize("model_intercept", [True, False])
 def test_permuted_ols_check_h0_noeffect_labelswap_centered(model_intercept):
     """Check distributions of permutations when tested vars are centered."""
@@ -240,7 +238,7 @@ def test_permuted_ols_check_h0_noeffect_labelswap_centered(model_intercept):
     check_ktest_p_values_distribution_and_mse(all_kstest_pvals, all_mse)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 def test_permuted_ols_check_h0_noeffect_labelswap_uncentered():
     """Check distributions of permutations when tested vars are uncentered."""
     # create dummy design with no effect
@@ -256,7 +254,7 @@ def test_permuted_ols_check_h0_noeffect_labelswap_uncentered():
     check_ktest_p_values_distribution_and_mse(all_kstest_pvals, all_mse)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 def test_permuted_ols_check_h0_noeffect_signswap():
     """Check that h0 is close to the theoretical distribution \
     for permuted OLS with sign swap.
@@ -298,8 +296,6 @@ def test_permuted_ols_no_covar(design):
         model_intercept=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     compare_to_ref_score(output["t"], tested_var, target_var)
 
@@ -314,8 +310,6 @@ def test_permuted_ols_no_covar_with_ravelized_tested_var(design):
         model_intercept=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     compare_to_ref_score(output["t"], tested_var, target_var)
 
@@ -331,8 +325,6 @@ def test_permuted_ols_no_covar_with_intercept(design):
         model_intercept=True,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     target_var -= target_var.mean(0)
     tested_var -= tested_var.mean(0)
@@ -353,8 +345,6 @@ def test_permuted_ols_with_covar(design, confounding_vars):
         model_intercept=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     ref_score = compare_to_ref_score(
@@ -375,8 +365,6 @@ def test_permuted_ols_with_covar_with_intercept(design, confounding_vars):
         model_intercept=True,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     confounding_vars = np.hstack((confounding_vars, np.ones((N_SAMPLES, 1))))
@@ -404,8 +392,6 @@ def test_permuted_ols_with_covar_with_intercept_in_confonding_vars(
         model_intercept=model_intercept,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     assert output["t"].shape == (n_regressors, n_descriptors)
 
@@ -426,8 +412,6 @@ def test_permuted_ols_with_multiple_constants_and_covars(design, rng):
         model_intercept=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     assert output["t"].shape == (n_regressors, n_descriptors)
 
@@ -453,8 +437,6 @@ def test_permuted_ols_nocovar_multivariate(rng):
         model_intercept=False,
         n_perm=n_perm,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     compare_to_ref_score(output["t"], tested_var, target_vars)
@@ -469,8 +451,6 @@ def test_permuted_ols_nocovar_multivariate(rng):
         model_intercept=True,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     target_vars -= target_vars.mean(0)
@@ -496,8 +476,6 @@ def test_permuted_ols_intercept_nocovar(rng):
         confounding_vars=None,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     ref_score = compare_to_ref_score(output["t"], tested_var, target_var)
@@ -516,8 +494,6 @@ def test_permuted_ols_intercept_nocovar(rng):
         model_intercept=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     compare_to_ref_score(output_addintercept["t"], tested_var, target_var)
     assert output_addintercept["t"].shape == (n_regressors, n_descriptors)
@@ -540,8 +516,6 @@ def test_permuted_ols_intercept_statsmodels_withcovar(
         confounding_vars,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     ref_score = compare_to_ref_score(
         output["t"], tested_var, target_var, confounding_vars
@@ -557,8 +531,6 @@ def test_permuted_ols_intercept_statsmodels_withcovar(
         model_intercept=True,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     compare_to_ref_score(
         output_intercept["t"], tested_var, target_var, confounding_vars
@@ -583,8 +555,6 @@ def test_one_sided_versus_two_test(rng):
         two_sided_test=False,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     assert output_1_sided["logp_max_t"].shape == (n_regressors, n_descriptors)
 
@@ -596,8 +566,6 @@ def test_one_sided_versus_two_test(rng):
         two_sided_test=True,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     assert output_2_sided["logp_max_t"].shape == (n_regressors, n_descriptors)
 
@@ -628,8 +596,6 @@ def test_two_sided_recover_positive_and_negative_effects():
         two_sided_test=False,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     output_1_sided_1["logp_max_t"]
 
@@ -641,8 +607,6 @@ def test_two_sided_recover_positive_and_negative_effects():
         two_sided_test=False,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     # two-sided
@@ -653,8 +617,6 @@ def test_two_sided_recover_positive_and_negative_effects():
         two_sided_test=True,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
     output_2_sided["logp_max_t"]
 
@@ -668,6 +630,7 @@ def test_two_sided_recover_positive_and_negative_effects():
     )
 
 
+@pytest.mark.slow
 def test_tfce_smoke_legacy_smoke():
     """Check tfce output of dict with or without permutations."""
     (
@@ -689,8 +652,6 @@ def test_tfce_smoke_legacy_smoke():
         random_state=0,
         masker=masker,
         tfce=True,
-        output_type="dict",
-        verbose=1,
     )
 
     assert isinstance(out, dict)
@@ -711,8 +672,6 @@ def test_tfce_smoke_legacy_smoke():
         random_state=0,
         masker=masker,
         tfce=True,
-        output_type="dict",
-        verbose=1,
     )
 
     assert isinstance(out, dict)
@@ -730,6 +689,7 @@ def test_tfce_smoke_legacy_smoke():
     assert out["h0_max_tfce"].size == n_perm
 
 
+@pytest.mark.slow
 def test_cluster_level_parameters_smoke(cluster_level_design, masker):
     """Test combinations of parameters related to cluster-level inference."""
     target_var, tested_var = cluster_level_design
@@ -742,8 +702,6 @@ def test_cluster_level_parameters_smoke(cluster_level_design, masker):
         two_sided_test=False,
         n_perm=0,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     assert isinstance(out, dict)
@@ -761,8 +719,6 @@ def test_cluster_level_parameters_smoke(cluster_level_design, masker):
         random_state=0,
         threshold=0.001,
         masker=masker,
-        output_type="dict",
-        verbose=1,
     )
 
     assert isinstance(out, dict)
@@ -791,12 +747,13 @@ def test_sanitize_inputs_permuted_ols(design):
     )
 
 
+@pytest.mark.single_process
 def test_permuted_ols_warnings_n_perm_n_job(cluster_level_design, masker):
     """Check that proper warning are thrown depending on n_job VS n_perm."""
     target_var, tested_var = cluster_level_design
 
     # n_perm > n_job --> no warning
-    with pytest.warns() as record:
+    with warnings.catch_warnings(record=True) as warning_list:
         permuted_ols(
             tested_var,
             target_var,
@@ -805,7 +762,7 @@ def test_permuted_ols_warnings_n_perm_n_job(cluster_level_design, masker):
             masker=masker,
         )
     assert all(
-        "perform more permutations" not in str(x.message) for x in record
+        "perform more permutations" not in str(x.message) for x in warning_list
     )
 
     # n_perm <= n_job  and n_job > 0 -->  warning
@@ -823,8 +780,8 @@ def test_cluster_level_parameters_warnings(cluster_level_design, masker):
     # masker is defined, but threshold is not.
     # no cluster-level inference is performed, but there's a warning.
     with pytest.warns(
-        DeprecationWarning,
-        match='"legacy" output structure for "permuted_ols" is deprecated',
+        FutureWarning,
+        match="'output_type'.*is deprecated",
     ):
         out = permuted_ols(
             tested_var,
@@ -843,7 +800,7 @@ def test_cluster_level_parameters_warnings(cluster_level_design, masker):
     # raise a warning, and get a dictionary.
     with pytest.warns(
         Warning,
-        match='If "threshold" is not None',
+        match="If 'threshold' is not None",
     ):
         out = permuted_ols(
             tested_var,
@@ -886,8 +843,6 @@ def test_permuted_ols_no_covar_warning(rng):
         model_intercept=False,
         n_perm=N_PERM,
         random_state=0,
-        output_type="dict",
-        verbose=1,
     )
 
     # test with ravelized tested_var
@@ -900,7 +855,6 @@ def test_permuted_ols_no_covar_warning(rng):
             model_intercept=False,
             n_perm=N_PERM,
             random_state=0,
-            output_type="dict",
         )
 
     assert np.array_equal(output_1["t"][1:], output_2["t"][1:])
@@ -977,7 +931,7 @@ def test_permuted_ols_no_covar_n_job_error(dummy_design):
     target_var, tested_var, *_ = dummy_design
 
     with pytest.raises(
-        ValueError, match="'n_jobs == 0' is not a valid choice."
+        ValueError, match=r"'n_jobs == 0' is not a valid choice."
     ):
         permuted_ols(
             tested_var,
@@ -991,7 +945,7 @@ def test_permuted_ols_target_vars_error(dummy_design):
     target_var, tested_var, *_ = dummy_design
 
     with pytest.raises(
-        ValueError, match="'target_vars' should be a 2D array."
+        ValueError, match=r"'target_vars' should be a 2D array."
     ):
         permuted_ols(
             tested_var,
@@ -1003,7 +957,7 @@ def test_permuted_ols_type_n_perm(dummy_design):
     """Checks type n_perm."""
     target_var, tested_var, *_ = dummy_design
 
-    with pytest.raises(TypeError, match="'n_perm' should be of type"):
+    with pytest.raises(TypeError, match="'n_perm' must be of type"):
         permuted_ols(tested_var, target_var, n_perm=0.1)
 
 
@@ -1030,7 +984,7 @@ def test_cluster_level_parameters_error_no_masker(cluster_level_design):
     # but masker is not defined.
     with pytest.raises(
         ValueError,
-        match='If "threshold" is not None, masker must be defined as well.',
+        match=r"If 'threshold' is not None, masker must be defined as well.",
     ):
         permuted_ols(
             tested_var,
