@@ -1,13 +1,11 @@
 """Matplotlib colormaps useful for neuroimaging."""
 
-import matplotlib
 import numpy as _np
 from matplotlib import cm as _cm
+from matplotlib import colormaps as _colormaps
 from matplotlib import colors as _colors
 from matplotlib import rcParams as _rcParams
 
-from nilearn._utils.helpers import compare_version
-
 ###############################################################################
 # Custom colormaps for two-tailed symmetric statistics
 
@@ -96,7 +94,7 @@ def _concat_cmap(cmap1, cmap2):
             cdict[c] = []
         ps = _np.linspace(0, 1, 10)
         colors = cmap1(ps)
-        for p, (r, g, b, _) in zip(ps, colors):
+        for p, (r, g, b, _) in zip(ps, colors, strict=False):
             cdict["red"].append((0.5 * p, r, r))
             cdict["green"].append((0.5 * p, g, g))
             cdict["blue"].append((0.5 * p, b, b))
@@ -108,7 +106,7 @@ def _concat_cmap(cmap1, cmap2):
     else:
         ps = _np.linspace(0, 1, 10)
         colors = cmap2(ps)
-        for p, (r, g, b, _) in zip(ps, colors):
+        for p, (r, g, b, _) in zip(ps, colors, strict=False):
             cdict["red"].append((0.5 * (1 + p), r, r))
             cdict["green"].append((0.5 * (1 + p), g, g))
             cdict["blue"].append((0.5 * (1 + p), b, b))
@@ -283,14 +281,7 @@ _cmap_d["videen_style"] = _colors.LinearSegmentedColormap.from_list(
 globals().update(_cmap_d)
 # Register cmaps in matplotlib too
 for k, v in _cmap_d.items():
-    if compare_version(matplotlib.__version__, ">=", "3.5.0"):
-        from matplotlib import colormaps as _colormaps
-
-        _register_cmap = _colormaps.register
-    else:
-        _register_cmap = _cm.register_cmap
-
-    _register_cmap(name=k, cmap=v)
+    _colormaps.register(name=k, cmap=v)
 
 
 ###############################################################################
@@ -346,7 +337,7 @@ def replace_inside(outer_cmap, inner_cmap, vmin, vmax):
             this_cdict["red"] = []
             this_cdict["green"] = []
             this_cdict["blue"] = []
-            for p, (r, g, b, _) in zip(ps, colors):
+            for p, (r, g, b, _) in zip(ps, colors, strict=False):
                 this_cdict["red"].append((p, r, r))
                 this_cdict["green"].append((p, g, g))
                 this_cdict["blue"].append((p, b, b))
