@@ -18,10 +18,15 @@ from nilearn._utils.extmath import fast_abs_percentile
 from nilearn._utils.html_document import HTMLDocument
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import safe_get_data
-from nilearn._utils.niimg_conversions import check_niimg_3d
 from nilearn._utils.param_validation import check_threshold
 from nilearn.datasets import load_mni152_template
-from nilearn.image import get_data, new_img_like, reorder_img, resample_to_img
+from nilearn.image import (
+    check_niimg_3d,
+    get_data,
+    new_img_like,
+    reorder_img,
+    resample_to_img,
+)
 from nilearn.plotting._engine_utils import colorscale
 from nilearn.plotting.find_cuts import find_xyz_cut_coords
 from nilearn.plotting.image.utils import load_anat
@@ -232,7 +237,7 @@ def _mask_stat_map(stat_map_img, threshold=None):
     return mask_img, stat_map_img, data, threshold
 
 
-def _load_bg_img(stat_map_img, bg_img="MNI152", black_bg="auto", dim="auto"):
+def load_bg_img(stat_map_img, bg_img="MNI152", black_bg="auto", dim="auto"):
     """Load and resample bg_img in an isotropic resolution, \
     with a positive diagonal affine matrix.
 
@@ -265,7 +270,7 @@ def _load_bg_img(stat_map_img, bg_img="MNI152", black_bg="auto", dim="auto"):
         bg_img, black_bg, bg_min, bg_max = load_anat(
             bg_img, dim=dim, black_bg=black_bg
         )
-    bg_img = reorder_img(bg_img, resample="nearest", copy_header=True)
+    bg_img = reorder_img(bg_img, resample="nearest")
     return bg_img, bg_min, bg_max, black_bg
 
 
@@ -281,19 +286,10 @@ def _resample_stat_map(
     mask_img
     """
     stat_map_img = resample_to_img(
-        stat_map_img,
-        bg_img,
-        interpolation=resampling_interpolation,
-        copy_header=True,
-        force_resample=False,  # TODO (nilearn >= 0.13.0) update to True
+        stat_map_img, bg_img, interpolation=resampling_interpolation
     )
     mask_img = resample_to_img(
-        mask_img,
-        bg_img,
-        fill_value=1,
-        interpolation="nearest",
-        copy_header=True,
-        force_resample=False,  # TODO (nilearn >= 0.13.0) update to True
+        mask_img, bg_img, fill_value=1, interpolation="nearest"
     )
 
     return stat_map_img, mask_img
@@ -626,6 +622,11 @@ def view_img(
     opacity : :obj:`float` in [0,1], default=1
         The level of opacity of the overlay (0: transparent, 1: opaque).
 
+    %(radiological)s
+
+    show_lr : :obj:`bool`, default=True
+        Show left and right labels on the figure
+
     Returns
     -------
     html_view : the html viewer object.
@@ -661,7 +662,7 @@ def view_img(
     )
 
     # Prepare the data for the cuts
-    bg_img, bg_min, bg_max, black_bg = _load_bg_img(
+    bg_img, bg_min, bg_max, black_bg = load_bg_img(
         stat_map_img, bg_img, black_bg, dim
     )
     stat_map_img, mask_img = _resample_stat_map(
