@@ -6,21 +6,21 @@ import numpy as np
 import pytest
 
 from nilearn import datasets, image
-from nilearn._utils.exceptions import DimensionError
 from nilearn.datasets import fetch_surf_fsaverage
+from nilearn.exceptions import DimensionError
 from nilearn.image import get_data
 from nilearn.plotting.js_plotting_utils import decode
 from nilearn.plotting.surface.html_surface import (
     _fill_html_template,
     _full_brain_info,
     _one_mesh_info,
-    full_brain_info,
-    one_mesh_info,
     view_img_on_surf,
     view_surf,
 )
 from nilearn.plotting.tests.test_engine_utils import check_colors
-from nilearn.plotting.tests.test_js_plotting_utils import check_html
+from nilearn.plotting.tests.test_js_plotting_utils import (
+    check_html_surface_plots,
+)
 from nilearn.surface.surface import (
     check_mesh_is_fsaverage,
     load_surf_data,
@@ -68,15 +68,6 @@ def test_one_mesh_info():
     assert not info["full_brain_mesh"]
     check_colors(info["colorscale"])
 
-    # TODO (nilearn >= 0.13.0)
-    with pytest.warns(
-        DeprecationWarning,
-        match="one_mesh_info is a private function and is renamed "
-        "to _one_mesh_info. Using the deprecated name will "
-        "raise an error in release 0.13",
-    ):
-        one_mesh_info(surf_map, mesh)
-
 
 def test_full_brain_info(mni152_template_res_2):
     surfaces = datasets.fetch_surf_fsaverage()
@@ -106,15 +97,6 @@ def test_full_brain_info(mni152_template_res_2):
             mesh.faces
         )
 
-    # TODO (nilearn >= 0.13.0)
-    with pytest.warns(
-        DeprecationWarning,
-        match="full_brain_info is a private function and is renamed to "
-        "_full_brain_info. Using the deprecated name will raise an error "
-        "in release 0.13",
-    ):
-        full_brain_info(mni152_template_res_2)
-
 
 def test_fill_html_template(tmp_path, mni152_template_res_2):
     fsaverage = fetch_surf_fsaverage()
@@ -128,13 +110,18 @@ def test_fill_html_template(tmp_path, mni152_template_res_2):
         bg_map=fsaverage["sulc_right"],
     )
     info["title"] = None
+
     html = _fill_html_template(info, embed_js=False)
-    check_html(tmp_path, html)
+
+    check_html_surface_plots(tmp_path, html)
     assert "jquery.min.js" in html.html
+
     info = _full_brain_info(mni152_template_res_2)
     info["title"] = None
+
     html = _fill_html_template(info)
-    check_html(tmp_path, html)
+
+    check_html_surface_plots(tmp_path, html)
     assert "* plotly.js (gl3d - minified) v1." in html.html
 
 
@@ -142,10 +129,12 @@ def test_view_surf(tmp_path, rng):
     fsaverage = fetch_surf_fsaverage()
     mesh = load_surf_mesh(fsaverage["pial_right"])
     surf_map = mesh.coordinates[:, 0]
+
     html = view_surf(
         fsaverage["pial_right"], surf_map, fsaverage["sulc_right"], "90%"
     )
-    check_html(tmp_path, html, title="Surface plot")
+    check_html_surface_plots(tmp_path, html, title="Surface plot")
+
     html = view_surf(
         fsaverage["pial_right"],
         surf_map,
@@ -153,63 +142,70 @@ def test_view_surf(tmp_path, rng):
         0.3,
         title="SOME_TITLE",
     )
-    check_html(tmp_path, html, title="SOME_TITLE")
-    assert "SOME_TITLE" in html.html
+    check_html_surface_plots(tmp_path, html, title="SOME_TITLE")
+
     html = view_surf(fsaverage["pial_right"])
-    check_html(tmp_path, html)
+    check_html_surface_plots(tmp_path, html)
+
     atlas = rng.integers(0, 10, size=len(mesh.coordinates))
     html = view_surf(fsaverage["pial_left"], atlas, symmetric_cmap=False)
-    check_html(tmp_path, html)
+    check_html_surface_plots(tmp_path, html)
+
     html = view_surf(
         fsaverage["pial_right"],
         fsaverage["sulc_right"],
         threshold=None,
         cmap="Greys",
     )
-    check_html(tmp_path, html)
+    check_html_surface_plots(tmp_path, html)
+
+
+def test_view_surf_errors():
+    fsaverage = fetch_surf_fsaverage()
+    mesh = load_surf_mesh(fsaverage["pial_right"])
+
     with pytest.raises(ValueError):
         view_surf(mesh, mesh.coordinates[::2, 0])
+
     with pytest.raises(ValueError):
         view_surf(
             mesh, mesh.coordinates[:, 0], bg_map=mesh.coordinates[::2, 0]
         )
 
 
-def test_view_img_on_surf(tmp_path, mni152_template_res_2):
-    html = view_img_on_surf(mni152_template_res_2, threshold="92.3%")
-    check_html(tmp_path, html)
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"threshold": "92.3%"},
+        {"threshold": 0, "surf_mesh": datasets.fetch_surf_fsaverage()},
+        {"threshold": 0.4, "title": "SOME_TITLE"},
+        {"threshold": 0.4, "cmap": "hot", "black_bg": True},
+    ],
+)
+def test_view_img_on_surf(tmp_path, mni152_template_res_2, kwargs):
+    """Check output of view_img_on_surf."""
+    html = view_img_on_surf(mni152_template_res_2, **kwargs)
+    check_html_surface_plots(tmp_path, html, title=kwargs.get("title", None))
 
-    surfaces = datasets.fetch_surf_fsaverage()
-    html = view_img_on_surf(
-        mni152_template_res_2, threshold=0, surf_mesh=surfaces
-    )
-    check_html(tmp_path, html)
-
-    html = view_img_on_surf(
-        mni152_template_res_2, threshold=0.4, title="SOME_TITLE"
-    )
-    assert "SOME_TITLE" in html.html
-    check_html(tmp_path, html)
-
-    html = view_img_on_surf(
-        mni152_template_res_2, threshold=0.4, cmap="hot", black_bg=True
-    )
-    check_html(tmp_path, html)
 
+def test_view_img_on_surf_clipped_image(tmp_path, mni152_template_res_2):
+    """Check output of view_img_on_surf with clipped input."""
     img_4d = image.new_img_like(
         mni152_template_res_2,
         get_data(mni152_template_res_2)[:, :, :, np.newaxis],
     )
     assert len(img_4d.shape) == 4
-
     np.clip(
         get_data(mni152_template_res_2),
         0,
         None,
         out=get_data(mni152_template_res_2),
     )
+
     html = view_img_on_surf(mni152_template_res_2, symmetric_cmap=False)
-    check_html(tmp_path, html)
+
+    check_html_surface_plots(tmp_path, html)
 
     html = view_img_on_surf(
         mni152_template_res_2,
@@ -217,10 +213,10 @@ def test_view_img_on_surf(tmp_path, mni152_template_res_2):
         vol_to_surf_kwargs={
             "n_samples": 1,
             "radius": 0.0,
-            "interpolation": "nearest",
+            "interpolation": "nearest_most_frequent",
         },
     )
-    check_html(tmp_path, html)
+    check_html_surface_plots(tmp_path, html)
 
 
 def test_view_img_on_surf_input_as_file(img_3d_mni_as_file):
@@ -231,3 +227,12 @@ def test_view_img_on_surf_input_as_file(img_3d_mni_as_file):
 def test_view_img_on_surf_errors(img_3d_mni):
     with pytest.raises(DimensionError):
         view_img_on_surf([img_3d_mni, img_3d_mni])
+
+
+@pytest.mark.parametrize("view", ["left", "right"])
+def test_view_img_on_surf_view(tmp_path, mni152_template_res_2, view):
+    """Smoke test for different views of view_img_on_surf."""
+    html = view_img_on_surf(mni152_template_res_2, view=view)
+
+    assert f', "view": "{view}"' in str(html)
+    check_html_surface_plots(tmp_path, html)
