@@ -20,17 +20,17 @@ from nilearn.plotting.html_stat_map import (
     _json_view_params,
     _json_view_size,
     _json_view_to_html,
-    _load_bg_img,
     _mask_stat_map,
     _resample_stat_map,
     _save_cm,
     _save_sprite,
     _threshold_data,
+    load_bg_img,
     view_img,
 )
 
 
-def _check_html(html_view, title=None):
+def check_html_view_img(html_view, title=None):
     """Check the presence of some expected code in the html viewer."""
     assert isinstance(html_view, StatMapView)
     assert "var brain =" in str(html_view)
@@ -62,7 +62,7 @@ def _check_affine(affine):
     assert affine[2, 2] == affine[1, 1]
     assert affine[0, 0] > 0
 
-    A, b = image.resampling.to_matrix_vector(affine)
+    A, _ = image.resampling.to_matrix_vector(affine)
     assert np.all((np.abs(A) > 0.001).sum(axis=0) == 1), (
         "the affine transform was not near-diagonal"
     )
@@ -96,30 +96,30 @@ def test_threshold_data():
     data = np.arange(-3, 4)
 
     # Check that an 'auto' threshold leaves at least one element
-    data_t, mask, thresh = _threshold_data(data, threshold="auto")
+    data_t, mask, _ = _threshold_data(data, threshold="auto")
     gtruth_m = np.array([False, True, True, True, True, True, False])
     gtruth_d = np.array([-3, 0, 0, 0, 0, 0, 3])
     assert (mask == gtruth_m).all()
     assert (data_t == gtruth_d).all()
 
     # Check that threshold=None keeps everything
-    data_t, mask, thresh = _threshold_data(data, threshold=None)
+    data_t, mask, _ = _threshold_data(data, threshold=None)
     assert np.all(np.logical_not(mask))
     assert np.all(data_t == data)
 
     # Check positive threshold works
-    data_t, mask, thresh = _threshold_data(data, threshold=1)
+    data_t, mask, _ = _threshold_data(data, threshold=1)
     gtruth = np.array([False, False, True, True, True, False, False])
     assert (mask == gtruth).all()
 
     # Check 0 threshold works
-    data_t, mask, thresh = _threshold_data(data, threshold=0)
+    data_t, mask, _ = _threshold_data(data, threshold=0)
     gtruth = np.array([False, False, False, True, False, False, False])
     assert (mask == gtruth).all()
 
     # Check that overly lenient threshold returns array
     data = np.arange(3, 10)
-    data_t, mask, thresh = _threshold_data(data, threshold=2)
+    data_t, mask, _ = _threshold_data(data, threshold=2)
     gtruth = np.full(7, False)
     assert (mask == gtruth).all()
 
@@ -174,11 +174,11 @@ def test_mask_stat_map():
     img, data = _simulate_img()
 
     # Try not to threshold anything
-    mask_img, img, data_t, thresh = _mask_stat_map(img, threshold=None)
+    mask_img, img, _, _ = _mask_stat_map(img, threshold=None)
     assert np.max(get_data(mask_img)) == 0
 
     # Now threshold at zero
-    mask_img, img, data_t, thresh = _mask_stat_map(img, threshold=0)
+    mask_img, img, _, _ = _mask_stat_map(img, threshold=0)
     assert np.min((data == 0) == get_data(mask_img))
 
 
@@ -190,12 +190,12 @@ def test_load_bg_img(affine_eye):
     img, _ = _simulate_img(affine)
 
     # use empty bg_img
-    bg_img, _, _, _ = _load_bg_img(img, bg_img=None)
+    bg_img, _, _, _ = load_bg_img(img, bg_img=None)
     # Check positive isotropic, near-diagonal affine
     _check_affine(bg_img.affine)
 
     # Try to load the default background
-    bg_img, _, _, _ = _load_bg_img(img)
+    bg_img, _, _, _ = load_bg_img(img)
 
     # Check positive isotropic, near-diagonal affine
     _check_affine(bg_img.affine)
@@ -205,7 +205,7 @@ def test_get_bg_mask_and_cmap():
     # non-regression test for issue #3120 (bg image was masked with mni
     # template mask)
     img, _ = _simulate_img()
-    mask, cmap = _get_bg_mask_and_cmap(img, False)
+    mask, _ = _get_bg_mask_and_cmap(img, False)
     assert (mask == np.zeros(img.shape, dtype=bool)).all()
 
 
@@ -340,7 +340,7 @@ def test_json_view_to_html(affine_eye, black_bg, cbar, radiological):
 
     # Create a viewer
     html_view = _json_view_to_html(json_view)
-    _check_html(html_view)
+    check_html_view_img(html_view)
 
 
 def test_get_cut_slices(affine_eye):
@@ -366,6 +366,7 @@ def test_get_cut_slices(affine_eye):
     assert (cut_slices == [4, 4, 4]).all()
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "params, warning_msg",
     [
@@ -384,12 +385,7 @@ def test_view_img_3d_warnings(params, warning_msg):
     mni = datasets.load_mni152_template(resolution=2)
 
     # Create a fake functional image by resample the template
-    img = image.resample_img(
-        mni,
-        target_affine=3 * np.eye(3),
-        copy_header=True,
-        force_resample=True,
-    )
+    img = image.resample_img(mni, target_affine=3 * np.eye(3))
 
     # Should not raise warnings
     with warnings.catch_warnings(record=True) as w:
@@ -399,9 +395,10 @@ def test_view_img_3d_warnings(params, warning_msg):
     with pytest.warns(UserWarning, match=warning_msg):
         html_view = view_img(img, **params)
 
-    _check_html(html_view)
+    check_html_view_img(html_view)
 
 
+@pytest.mark.slow
 def test_view_img_3d_warnings_more():
     """Test warning when viewing 3D images.
 
@@ -410,12 +407,7 @@ def test_view_img_3d_warnings_more():
     mni = datasets.load_mni152_template(resolution=2)
 
     # Create a fake functional image by resample the template
-    img = image.resample_img(
-        mni,
-        target_affine=3 * np.eye(3),
-        copy_header=True,
-        force_resample=True,
-    )
+    img = image.resample_img(mni, target_affine=3 * np.eye(3))
 
     with pytest.warns(
         UserWarning,
@@ -423,7 +415,7 @@ def test_view_img_3d_warnings_more():
     ):
         html_view = view_img(img)
 
-    _check_html(html_view, title="Slice viewer")
+    check_html_view_img(html_view, title="Slice viewer")
 
     with pytest.warns(
         UserWarning,
@@ -431,7 +423,7 @@ def test_view_img_3d_warnings_more():
     ):
         html_view = view_img(img, threshold="95%", title="SOME_TITLE")
 
-    _check_html(html_view, title="SOME_TITLE")
+    check_html_view_img(html_view, title="SOME_TITLE")
 
 
 @pytest.mark.parametrize(
@@ -447,12 +439,7 @@ def test_view_img_4d_warnings(params):
     mni = datasets.load_mni152_template(resolution=2)
 
     # Create a fake functional image by resample the template
-    img = image.resample_img(
-        mni,
-        target_affine=3 * np.eye(3),
-        copy_header=True,
-        force_resample=True,
-    )
+    img = image.resample_img(mni, target_affine=3 * np.eye(3))
     img_4d = image.new_img_like(img, get_data(img)[:, :, :, np.newaxis])
     assert len(img_4d.shape) == 4
 
@@ -462,4 +449,4 @@ def test_view_img_4d_warnings(params):
     ):
         html_view = view_img(img_4d, **params)
 
-    _check_html(html_view)
+    check_html_view_img(html_view)
