@@ -15,10 +15,9 @@ from nilearn import masking
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import safe_get_data
-from nilearn._utils.niimg_conversions import check_niimg_3d, check_niimg_4d
 from nilearn._utils.numpy_conversions import as_ndarray
 from nilearn._utils.param_validation import check_reduction_strategy
-from nilearn.image import new_img_like
+from nilearn.image import check_niimg_3d, check_niimg_4d, new_img_like
 
 INF = 1000 * np.finfo(np.float32).eps
 
@@ -113,7 +112,7 @@ def _get_labels_data(
     mask_img=None,
     background_label=0,
     dim=None,
-    keep_masked_labels=True,
+    keep_masked_labels=False,
 ):
     """Get the label data.
 
@@ -143,6 +142,7 @@ def _get_labels_data(
 
     dim : :obj:`int`, optional
         Integer slices mask for a specific dimension.
+
     %(keep_masked_labels)s
 
     Returns
@@ -168,17 +168,13 @@ def _get_labels_data(
 
     if keep_masked_labels:
         labels = list(np.unique(labels_data))
-        # TODO (nilearn >= 0.13.0)
+        # TODO (nilearn >= 0.15.0)
         warnings.warn(
-            'Applying "mask_img" before '
-            "signal extraction may result in empty region signals in the "
-            "output. These are currently kept. "
-            "Starting from version 0.13, the default behavior will be "
-            "changed to remove them by setting "
-            '"keep_masked_labels=False". '
-            '"keep_masked_labels" parameter will be removed '
-            "in version 0.15.",
-            DeprecationWarning,
+            (
+                "In version 0.15.0, "
+                '"keep_masked_labels" parameter will be removed.'
+            ),
+            FutureWarning,
             stacklevel=find_stack_level(),
         )
 
@@ -224,7 +220,7 @@ def img_to_signals_labels(
     background_label=0,
     order="F",
     strategy="mean",
-    keep_masked_labels=True,
+    keep_masked_labels=False,
     return_masked_atlas=False,
 ):
     """Extract region signals from image.
@@ -262,8 +258,14 @@ def img_to_signals_labels(
 
     return_masked_atlas : :obj:`bool`, default=False
         If True, the masked atlas is returned.
-        deprecated in version 0.13, to be removed in 0.15.
-        after 0.13, the masked atlas will always be returned.
+
+        .. nilearn_versionchanged :: 0.13.0dev
+
+            Default changed to False.
+
+        .. nilearn_deprecated:: 0.13.0dev
+
+            This parameter will be removed in versions >= 0.15.0
 
     Returns
     -------
@@ -329,13 +331,13 @@ def img_to_signals_labels(
         )
         return signals, labels, masked_atlas
     else:
-        # TODO (nilearn >= 0.14.0)
+        # TODO (nilearn >= 0.15.0)
         warnings.warn(
-            'After version 0.13. "img_to_signals_labels" will also return the '
-            '"masked_atlas". Meanwhile "return_masked_atlas" parameter can be '
-            "used to toggle this behavior. In version 0.15, "
-            '"return_masked_atlas" parameter will be removed.',
-            DeprecationWarning,
+            (
+                "In version 0.15, "
+                '"return_masked_atlas" parameter will be removed.'
+            ),
+            FutureWarning,
             stacklevel=find_stack_level(),
         )
         return signals, labels
@@ -351,7 +353,7 @@ def signals_to_img_labels(
 
     labels_img, mask_img must have the same shapes and affines.
 
-    .. versionchanged:: 0.9.2
+    .. nilearn_versionchanged:: 0.9.2
         Support 1D signals.
 
     Parameters
@@ -430,7 +432,7 @@ def signals_to_img_labels(
 
 
 @fill_doc
-def img_to_signals_maps(imgs, maps_img, mask_img=None, keep_masked_maps=True):
+def img_to_signals_maps(imgs, maps_img, mask_img=None, keep_masked_maps=False):
     """Extract region signals from image.
 
     This function is applicable to regions defined by maps.
@@ -450,6 +452,7 @@ def img_to_signals_maps(imgs, maps_img, mask_img=None, keep_masked_maps=True):
         Mask to apply to regions before extracting signals.
         Every point outside the mask is considered
         as background (i.e. outside of any region).
+
     %(keep_masked_maps)s
 
     Returns
@@ -490,17 +493,15 @@ def img_to_signals_maps(imgs, maps_img, mask_img=None, keep_masked_maps=True):
         )
         maps_mask = as_ndarray(maps_mask, dtype=bool)
         if keep_masked_maps:
-            # TODO (nilearn >= 0.13.0)
+            # TODO (nilearn >= 0.15.0)
             warnings.warn(
                 'Applying "mask_img" before '
                 "signal extraction may result in empty region signals in the "
-                "output. These are currently kept. "
-                "Starting from version 0.13, the default behavior will be "
-                "changed to remove them by setting "
-                '"keep_masked_maps=False". '
+                "output. These are currently kept.\n"
                 '"keep_masked_maps" parameter will be removed '
-                "in version 0.15.",
-                DeprecationWarning,
+                "in version 0.15. "
+                'Set "keep_masked_maps=False" to silence this warning.',
+                FutureWarning,
                 stacklevel=find_stack_level(),
             )
         else:
