@@ -10,10 +10,10 @@ from nilearn._utils.estimator_checks import (
     check_estimator,
     nilearn_check_estimator,
 )
-from nilearn._utils.exceptions import DimensionError
 from nilearn._utils.tags import SKLEARN_LT_1_6
 from nilearn.conftest import _affine_eye, _img_4d_zeros, _shape_3d_large
-from nilearn.image import get_data
+from nilearn.exceptions import DimensionError
+from nilearn.image import get_data, threshold_img
 from nilearn.regions import (
     RegionExtractor,
     connected_label_regions,
@@ -95,6 +95,7 @@ else:
         return_expected_failed_checks,
     )
 
+    @pytest.mark.slow
     @parametrize_with_checks(
         estimators=ESTIMATORS_TO_CHECK,
         expected_failed_checks=return_expected_failed_checks,
@@ -104,7 +105,7 @@ else:
         check(estimator)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "estimator, check, name",
     nilearn_check_estimator(
@@ -171,9 +172,7 @@ def test_threshold_maps_ratio_3d(map_img_3d):
 def test_invalids_extract_types_in_connected_regions(
     dummy_map, invalid_extract_type
 ):
-    valid_names = ["connected_components", "local_regions"]
-    message = f"'extract_type' should be {valid_names}"
-    with pytest.raises(ValueError, match=message):
+    with pytest.raises(ValueError, match="'extract_type' must be one of"):
         connected_regions(dummy_map, extract_type=invalid_extract_type)
 
 
@@ -243,14 +242,35 @@ def test_connected_regions_different_results_with_different_mask_images(
     )
 
 
+def test_connected_regions_no_regions(map_img_3d):
+    """Test if nilearn.regions.region_extractor.connected_regions raises
+    warning when no supra-threshold regions are found.
+
+    See issue : https://github.com/nilearn/nilearn/issues/5906
+    """
+    pos_thresholded_img = threshold_img(
+        map_img_3d,
+        threshold="99.9%",
+        copy=True,
+        two_sided=False,
+        copy_header=True,
+    )
+    with pytest.warns(UserWarning, match="No supra threshold regions"):
+        pos_regions_img, pos_index = connected_regions(
+            pos_thresholded_img, min_region_size=1000
+        )
+
+        assert pos_regions_img is None
+        assert pos_index is None
+
+
 def test_invalid_threshold_strategies(dummy_map):
     extract_strategy_check = RegionExtractor(
         dummy_map, thresholding_strategy="n_"
     )
 
     with pytest.raises(
-        ValueError,
-        match="'thresholding_strategy' should be ",
+        ValueError, match="'thresholding_strategy' must be one of"
     ):
         extract_strategy_check.fit()
 
@@ -260,7 +280,7 @@ def test_threshold_as_none_and_string_cases(dummy_map, threshold):
     to_check = RegionExtractor(dummy_map, threshold=threshold)
 
     with pytest.raises(
-        ValueError, match="The given input to threshold is not valid."
+        ValueError, match=r"The given input to threshold is not valid."
     ):
         to_check.fit()
 
@@ -327,6 +347,7 @@ def test_region_extractor_two_sided(maps):
     )
 
 
+@pytest.mark.slow
 def test_region_extractor_strategy_percentile(maps_and_mask):
     maps, mask_img = maps_and_mask
 
@@ -391,11 +412,11 @@ def test_region_extractor_zeros_affine_diagonal(affine_eye, n_regions):
 
 def test_error_messages_connected_label_regions(img_labels):
     with pytest.raises(
-        ValueError, match="Expected 'min_size' to be specified as integer."
+        ValueError, match=r"Expected 'min_size' to be specified as integer."
     ):
         connected_label_regions(labels_img=img_labels, min_size="a")
     with pytest.raises(
-        ValueError, match="'connect_diag' must be specified as True or False."
+        ValueError, match=r"'connect_diag' must be specified as True or False."
     ):
         connected_label_regions(labels_img=img_labels, connect_diag=None)
 
@@ -409,7 +430,7 @@ def test_remove_small_regions(affine_eye):
         ]
     )
     # To remove small regions, data should be labeled
-    label_map, n_labels = label(data)
+    label_map, _ = label(data)
     sum_label_data = np.sum(label_map)
 
     min_size = 10
