@@ -13,6 +13,7 @@ from sklearn.exceptions import EfficiencyWarning
 
 from nilearn import datasets, image
 from nilearn._utils import data_gen
+from nilearn._utils.helpers import is_windows_platform
 from nilearn.image import resampling
 from nilearn.surface.surface import (
     FileMesh,
@@ -37,7 +38,9 @@ from nilearn.surface.surface import (
     check_mesh_and_data,
     check_mesh_is_fsaverage,
     check_surf_img,
+    compute_adjacency_matrix,
     extract_data,
+    find_surface_clusters,
     get_data,
     load_surf_data,
     load_surf_mesh,
@@ -91,7 +94,7 @@ def test_check_mesh_and_data(rng, in_memory_mesh):
     # with the resulting wrong mesh
     with pytest.raises(
         ValueError,
-        match="Mismatch between .* indices of faces .* number of nodes.",
+        match=r"Mismatch between .* indices of faces .* number of nodes.",
     ):
         InMemoryMesh(in_memory_mesh.coordinates, wrong_faces)
 
@@ -458,25 +461,34 @@ def test_vertex_outer_normals():
     assert_array_almost_equal(computed_normals, true_normals)
 
 
-def test_load_uniform_ball_cloud():
+@pytest.mark.parametrize("n_points", [10, 20, 40, 80, 160])
+def test_load_uniform_ball_cloud_no_warning(n_points):
+    """Test that loading precomputed point clouds does not raise warnings.
+
+    Only for number of points: 10, 20, 40, 80, 160
+    """
     # Note: computed and shipped point clouds may differ since KMeans results
     # change after
     # https://github.com/scikit-learn/scikit-learn/pull/9288
     # but the exact position of the points does not matter as long as they are
     # well spread inside the unit ball
-    for n_points in [10, 20, 40, 80, 160]:
-        with warnings.catch_warnings(record=True) as w:
-            points = _load_uniform_ball_cloud(n_points=n_points)
-            assert_array_equal(points.shape, (n_points, 3))
-            assert len(w) == 0
+    with warnings.catch_warnings(record=True) as w:
+        points = _load_uniform_ball_cloud(n_points=n_points)
+        assert_array_equal(points.shape, (n_points, 3))
+        assert len(w) == 0
+
+
+@pytest.mark.flaky(reruns=5, reruns_delay=2, condition=is_windows_platform())
+@pytest.mark.parametrize("n_points", [3, 7])
+def test_load_uniform_ball_cloud(n_points):
+    """Test requesting n points with no cached results match computation."""
     with pytest.warns(EfficiencyWarning):
-        _load_uniform_ball_cloud(n_points=3)
-    for n_points in [3, 7]:
-        computed = _uniform_ball_cloud(n_points)
         loaded = _load_uniform_ball_cloud(n_points)
-        assert_array_almost_equal(computed, loaded)
-        assert (np.std(computed, axis=0) > 0.1).all()
-        assert (np.linalg.norm(computed, axis=1) <= 1).all()
+
+    computed = _uniform_ball_cloud(n_points)
+    assert_array_almost_equal(computed, loaded)
+    assert (np.std(computed, axis=0) > 0.1).all()
+    assert (np.linalg.norm(computed, axis=1) <= 1).all()
 
 
 def test_sample_locations():
@@ -553,7 +565,9 @@ def test_sample_locations_between_surfaces(depth, n_points, affine_eye):
             [
                 np.linspace(b, a, n_points)
                 for (a, b) in zip(
-                    inner.coordinates.ravel(), outer.coordinates.ravel()
+                    inner.coordinates.ravel(),
+                    outer.coordinates.ravel(),
+                    strict=False,
                 )
             ]
         )
@@ -575,10 +589,10 @@ def test_vol_to_surf_errors():
     img, *_ = data_gen.generate_mni_space_img()
     mesh = load_surf_mesh(datasets.fetch_surf_fsaverage()["pial_left"])
 
-    with pytest.raises(ValueError, match=".*does not support.*"):
+    with pytest.raises(ValueError, match=r".*does not support.*"):
         vol_to_surf(img, mesh, kind="ball", depth=[0.5])
 
-    with pytest.raises(ValueError, match=".*interpolation.*"):
+    with pytest.raises(ValueError, match=r".*interpolation.*"):
         vol_to_surf(img, mesh, interpolation="bad")
 
 
@@ -627,18 +641,6 @@ def test_vol_to_surf_nearest_most_frequent(img_labels):
     assert set(uniques_surf) <= set(uniques_vol)
 
 
-def test_vol_to_surf_nearest_deprecation(img_labels):
-    """Test deprecation warning for nearest interpolation method in
-    vol_to_surf.
-    """
-    # TODO (nilearn >= 0.13.0) deprecate nearest interpolation
-    mesh = flat_mesh(5, 7)
-    with pytest.warns(
-        FutureWarning, match="interpolation method will be deprecated"
-    ):
-        vol_to_surf(img_labels, mesh, interpolation="nearest")
-
-
 def test_masked_indices():
     mask = np.ones((4, 3, 8))
     mask[:, :, ::2] = 0
@@ -765,7 +767,7 @@ def test_choose_kind():
     assert kind == "line"
     kind = _choose_kind("auto", "mesh")
     assert kind == "depth"
-    with pytest.raises(TypeError, match=".*sampling strategy"):
+    with pytest.raises(TypeError, match=r".*sampling strategy"):
         kind = _choose_kind("depth", None)
 
 
@@ -781,14 +783,14 @@ def test_validate_mesh(rng):
     coords[0] = np.array([np.nan, np.nan, np.nan])
     faces = None
 
-    with pytest.raises(TypeError, match="must be numpy arrays."):
+    with pytest.raises(TypeError, match=r"must be numpy arrays."):
         InMemoryMesh(coordinates=coords, faces=faces)
 
     # coordinates is None
     faces = rng.integers(20, size=(30, 3))
     coords = None
 
-    with pytest.raises(TypeError, match="must be numpy arrays."):
+    with pytest.raises(TypeError, match=r"must be numpy arrays."):
         InMemoryMesh(coordinates=coords, faces=faces)
 
     # coordinates with non finite values
@@ -796,7 +798,7 @@ def test_validate_mesh(rng):
     coords[0] = np.array([np.nan, np.nan, np.nan])
     faces = rng.integers(coords.shape[0], size=(30, 3))
 
-    with pytest.raises(ValueError, match="Mesh coordinates must be finite."):
+    with pytest.raises(ValueError, match=r"Mesh coordinates must be finite."):
         InMemoryMesh(coordinates=coords, faces=faces)
 
     # faces with indices that do not correspond to any coordinate
@@ -807,7 +809,7 @@ def test_validate_mesh(rng):
 
     with pytest.raises(
         ValueError,
-        match="Mismatch between the indices of faces and the number of nodes.",
+        match=r".*between the indices of faces and the number of nodes.",
     ):
         InMemoryMesh(coordinates=coords, faces=faces)
 
@@ -816,7 +818,7 @@ def test_validate_mesh(rng):
 
     with pytest.raises(
         ValueError,
-        match="Mismatch between the indices of faces and the number of nodes.",
+        match=r".*between the indices of faces and the number of nodes.",
     ):
         InMemoryMesh(coordinates=coords, faces=faces)
 
@@ -925,7 +927,7 @@ def test_surface_image_shape(surf_img_2d, shape):
 
 
 def test_data_shape_not_matching_mesh(surf_img_1d, flip_surf_img_parts):
-    with pytest.raises(ValueError, match="shape.*vertices"):
+    with pytest.raises(ValueError, match=r"shape.*vertices"):
         SurfaceImage(surf_img_1d.mesh, flip_surf_img_parts(surf_img_1d.data))
 
 
@@ -1017,7 +1019,7 @@ def test_save_mesh_error(tmp_path, surf_img_1d):
 
 
 def test_save_mesh_error_wrong_suffix(tmp_path, surf_img_1d):
-    with pytest.raises(ValueError, match="with the extension '.gii'"):
+    with pytest.raises(ValueError, match=r"with the extension '.gii'"):
         surf_img_1d.mesh.to_filename(
             tmp_path / "hemi-L_hemi-R_cannot_have_both.foo"
         )
@@ -1156,7 +1158,7 @@ def test_surface_image_error():
     mesh_right = datasets.fetch_surf_fsaverage().pial_right
     mesh_left = datasets.fetch_surf_fsaverage().pial_left
 
-    with pytest.raises(TypeError, match="[PolyData, dict]"):
+    with pytest.raises(TypeError, match=r"[PolyData, dict]"):
         SurfaceImage(mesh={"left": mesh_left, "right": mesh_right}, data=3)
 
 
@@ -1193,7 +1195,7 @@ def test_get_min_max(surf_img_2d):
 
 def test_extract_data_wrong_input():
     """Check that only SurfaceImage is accepted as input."""
-    with pytest.raises(TypeError, match="Input must a be SurfaceImage"):
+    with pytest.raises(TypeError, match="must be of type"):
         extract_data(1, index=1)
 
 
@@ -1255,5 +1257,51 @@ def test_check_surf_img_dtype_error(surf_img_1d):
         "right": np.ones(surf_img_1d.data.parts["right"].shape, dtype="int32"),
     }
 
-    with pytest.raises(TypeError, match="All parts should have same dtype."):
+    with pytest.raises(TypeError, match=r"All parts should have same dtype."):
         SurfaceImage(surf_img_1d.mesh, data)
+
+
+# TODO check that clusters with same number of faces do not get same label
+
+
+def test_compute_adjacency_matrix(surf_mesh):
+    """Check basic content of an adjacency matrix.
+
+    - should be a square matrix determined by number of edges in mesh
+    - number of actually connected faces will actually depend on the
+      size of the mesh so it's very much hard coded for the mesh used here.
+    """
+    adjacency_matrix = compute_adjacency_matrix(surf_mesh.parts["left"])
+    assert adjacency_matrix.shape == (4, 4)
+    assert np.sum(np.sum(adjacency_matrix)) == 12
+
+    adjacency_matrix = compute_adjacency_matrix(surf_mesh.parts["right"])
+    assert adjacency_matrix.shape == (5, 5)
+    assert np.sum(np.sum(adjacency_matrix)) == 18
+
+
+@pytest.mark.parametrize(
+    "mask, expected_n_clusters",
+    [
+        ([False, False, False, False], 0),
+        ([True, False, False, False], 1),
+        ([True, True, True, True], 1),
+    ],
+)
+def test_find_surface_clusters_4_faces(mask, expected_n_clusters, surf_mesh):
+    clusters, _ = find_surface_clusters(surf_mesh.parts["left"], mask)
+    assert len(clusters) == expected_n_clusters
+
+
+@pytest.mark.parametrize(
+    "mask, expected_n_clusters",
+    [
+        ([False, False, False, False, False], 0),
+        ([True, False, False, False, False], 1),
+        ([False, True, False, True, False], 1),
+        ([True, True, True, True, True], 1),
+    ],
+)
+def test_find_surface_clusters_5_faces(mask, expected_n_clusters, surf_mesh):
+    clusters, _ = find_surface_clusters(surf_mesh.parts["right"], mask)
+    assert len(clusters) == expected_n_clusters
